Documentation
¶
Overview ¶
Package app provides the root command for the minder CLI
Index ¶
Constants ¶
const ( // JSON is the json format for output JSON = "json" // YAML is the yaml format for output YAML = "yaml" // Table is the table format for output Table = "table" )
Variables ¶
var ( // RootCmd represents the base command when called without any subcommands RootCmd = &cobra.Command{ Use: "minder", Short: "Minder controls the hosted minder service", Long: `For more information about minder, please visit: https://docs.stacklok.com/minder`, SilenceErrors: true, } )
Functions ¶
func Execute ¶
func Execute()
Execute adds all child commands to the root command and sets flags appropriately.
func IsOutputFormatSupported ¶ added in v0.0.22
IsOutputFormatSupported returns true if the output format is supported
func IsProviderSupported ¶ added in v0.0.22
IsProviderSupported returns true if the provider is supported
func SupportedOutputFormats ¶ added in v0.0.22
func SupportedOutputFormats() []string
SupportedOutputFormats returns the supported output formats
func SupportedProviders ¶ added in v0.0.22
func SupportedProviders() []string
SupportedProviders returns the supported providers list
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package artifact provides the artifact subcommands
|
Package artifact provides the artifact subcommands |
|
Package auth provides the auth command project for the minder CLI.
|
Package auth provides the auth command project for the minder CLI. |
|
Package apply provides the apply command for the minder CLI
|
Package apply provides the apply command for the minder CLI |
|
Package profile provides the CLI subcommand for managing profiles
|
Package profile provides the CLI subcommand for managing profiles |
|
status
Package status provides the CLI subcommand for managing profile statuses
|
Package status provides the CLI subcommand for managing profile statuses |
|
Package provider is the root command for the provider subcommands
|
Package provider is the root command for the provider subcommands |
|
Package quickstart provides the quickstart command for the minder CLI which is used to provide the means to quickly get started with minder.
|
Package quickstart provides the quickstart command for the minder CLI which is used to provide the means to quickly get started with minder. |
|
Package repo contains the repo logic for the control plane
|
Package repo contains the repo logic for the control plane |
|
Package ruletype provides the CLI subcommand for managing rules
|
Package ruletype provides the CLI subcommand for managing rules |
|
Package version provides the version command for the minder CLI
|
Package version provides the version command for the minder CLI |
Click to show internal directories.
Click to hide internal directories.