app

package
v0.0.21 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 14, 2023 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Overview

Package app provides the root command for the mindev CLI

Index

Constants

This section is empty.

Variables

var (

	// RootCmd represents the base command when called without any subcommands
	RootCmd = &cobra.Command{
		Use:   "mindev",
		Short: "mindev provides developer tooling for minder",
		Long: `For more information about minder, please visit:
https://docs.stacklok.com/minder`,
	}
)

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately.

Types

This section is empty.

Directories

Path Synopsis
Package rule_type provides the root command for the ruletype subcommands
Package rule_type provides the root command for the ruletype subcommands

Jump to