Documentation
¶
Overview ¶
Package database provides the database migration tooling for the minder application.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Migrator ¶
Migrator is the interface for the migration tooling.
func NewFromConnectionString ¶
NewFromConnectionString returns a new migration instance from the given connection string.
Click to show internal directories.
Click to hide internal directories.