mockdb

package
v0.0.53 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 26, 2024 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Overview

Package mockdb is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockStore

type MockStore struct {
	// contains filtered or unexported fields
}

MockStore is a mock of Store interface.

func NewMockStore

func NewMockStore(ctrl *gomock.Controller) *MockStore

NewMockStore creates a new mock instance.

func (*MockStore) BeginTransaction

func (m *MockStore) BeginTransaction() (*sql.Tx, error)

BeginTransaction mocks base method.

func (*MockStore) CheckHealth

func (m *MockStore) CheckHealth() error

CheckHealth mocks base method.

func (*MockStore) Commit

func (m *MockStore) Commit(arg0 *sql.Tx) error

Commit mocks base method.

func (*MockStore) CountProfilesByEntityType

func (m *MockStore) CountProfilesByEntityType(arg0 context.Context) ([]db.CountProfilesByEntityTypeRow, error)

CountProfilesByEntityType mocks base method.

func (*MockStore) CountProfilesByName added in v0.0.20

func (m *MockStore) CountProfilesByName(arg0 context.Context, arg1 string) (int64, error)

CountProfilesByName mocks base method.

func (*MockStore) CountRepositories added in v0.0.16

func (m *MockStore) CountRepositories(arg0 context.Context) (int64, error)

CountRepositories mocks base method.

func (*MockStore) CountUsers

func (m *MockStore) CountUsers(arg0 context.Context) (int64, error)

CountUsers mocks base method.

func (*MockStore) CreateInvitation added in v0.0.53

func (m *MockStore) CreateInvitation(arg0 context.Context, arg1 db.CreateInvitationParams) (db.UserInvite, error)

CreateInvitation mocks base method.

func (*MockStore) CreateProfile

func (m *MockStore) CreateProfile(arg0 context.Context, arg1 db.CreateProfileParams) (db.Profile, error)

CreateProfile mocks base method.

func (*MockStore) CreateProfileForEntity

func (m *MockStore) CreateProfileForEntity(arg0 context.Context, arg1 db.CreateProfileForEntityParams) (db.EntityProfile, error)

CreateProfileForEntity mocks base method.

func (*MockStore) CreateProject

func (m *MockStore) CreateProject(arg0 context.Context, arg1 db.CreateProjectParams) (db.Project, error)

CreateProject mocks base method.

func (*MockStore) CreateProjectWithID added in v0.0.27

func (m *MockStore) CreateProjectWithID(arg0 context.Context, arg1 db.CreateProjectWithIDParams) (db.Project, error)

CreateProjectWithID mocks base method.

func (*MockStore) CreateProvider

func (m *MockStore) CreateProvider(arg0 context.Context, arg1 db.CreateProviderParams) (db.Provider, error)

CreateProvider mocks base method.

func (*MockStore) CreatePullRequest

func (m *MockStore) CreatePullRequest(arg0 context.Context, arg1 db.CreatePullRequestParams) (db.PullRequest, error)

CreatePullRequest mocks base method.

func (*MockStore) CreateRepository

func (m *MockStore) CreateRepository(arg0 context.Context, arg1 db.CreateRepositoryParams) (db.Repository, error)

CreateRepository mocks base method.

func (*MockStore) CreateRuleType

func (m *MockStore) CreateRuleType(arg0 context.Context, arg1 db.CreateRuleTypeParams) (db.RuleType, error)

CreateRuleType mocks base method.

func (*MockStore) CreateSessionState

func (m *MockStore) CreateSessionState(arg0 context.Context, arg1 db.CreateSessionStateParams) (db.SessionStore, error)

CreateSessionState mocks base method.

func (*MockStore) CreateSubscription added in v0.0.37

func (m *MockStore) CreateSubscription(arg0 context.Context, arg1 db.CreateSubscriptionParams) (db.Subscription, error)

CreateSubscription mocks base method.

func (*MockStore) CreateUser

func (m *MockStore) CreateUser(arg0 context.Context, arg1 string) (db.User, error)

CreateUser mocks base method.

func (*MockStore) DeleteArtifact

func (m *MockStore) DeleteArtifact(arg0 context.Context, arg1 uuid.UUID) error

DeleteArtifact mocks base method.

func (*MockStore) DeleteExpiredSessionStates

func (m *MockStore) DeleteExpiredSessionStates(arg0 context.Context) (int64, error)

DeleteExpiredSessionStates mocks base method.

func (*MockStore) DeleteInstallationIDByAppID added in v0.0.39

func (m *MockStore) DeleteInstallationIDByAppID(arg0 context.Context, arg1 int64) error

DeleteInstallationIDByAppID mocks base method.

func (*MockStore) DeleteInvitation added in v0.0.53

func (m *MockStore) DeleteInvitation(arg0 context.Context, arg1 string) (db.UserInvite, error)

DeleteInvitation mocks base method.

func (*MockStore) DeleteNonUpdatedRules added in v0.0.52

func (m *MockStore) DeleteNonUpdatedRules(arg0 context.Context, arg1 db.DeleteNonUpdatedRulesParams) error

DeleteNonUpdatedRules mocks base method.

func (*MockStore) DeleteProfile

func (m *MockStore) DeleteProfile(arg0 context.Context, arg1 db.DeleteProfileParams) error

DeleteProfile mocks base method.

func (*MockStore) DeleteProfileForEntity added in v0.0.16

func (m *MockStore) DeleteProfileForEntity(arg0 context.Context, arg1 db.DeleteProfileForEntityParams) error

DeleteProfileForEntity mocks base method.

func (*MockStore) DeleteProject

func (m *MockStore) DeleteProject(arg0 context.Context, arg1 uuid.UUID) ([]db.DeleteProjectRow, error)

DeleteProject mocks base method.

func (*MockStore) DeleteProvider

func (m *MockStore) DeleteProvider(arg0 context.Context, arg1 db.DeleteProviderParams) error

DeleteProvider mocks base method.

func (*MockStore) DeletePullRequest

func (m *MockStore) DeletePullRequest(arg0 context.Context, arg1 db.DeletePullRequestParams) error

DeletePullRequest mocks base method.

func (*MockStore) DeleteRepository

func (m *MockStore) DeleteRepository(arg0 context.Context, arg1 uuid.UUID) error

DeleteRepository mocks base method.

func (*MockStore) DeleteRuleInstantiation added in v0.0.16

func (m *MockStore) DeleteRuleInstantiation(arg0 context.Context, arg1 db.DeleteRuleInstantiationParams) error

DeleteRuleInstantiation mocks base method.

func (*MockStore) DeleteRuleStatusesForProfileAndRuleType added in v0.0.16

func (m *MockStore) DeleteRuleStatusesForProfileAndRuleType(arg0 context.Context, arg1 db.DeleteRuleStatusesForProfileAndRuleTypeParams) error

DeleteRuleStatusesForProfileAndRuleType mocks base method.

func (*MockStore) DeleteRuleType

func (m *MockStore) DeleteRuleType(arg0 context.Context, arg1 uuid.UUID) error

DeleteRuleType mocks base method.

func (*MockStore) DeleteSessionStateByProjectID

func (m *MockStore) DeleteSessionStateByProjectID(arg0 context.Context, arg1 db.DeleteSessionStateByProjectIDParams) error

DeleteSessionStateByProjectID mocks base method.

func (*MockStore) DeleteUser

func (m *MockStore) DeleteUser(arg0 context.Context, arg1 int32) error

DeleteUser mocks base method.

func (*MockStore) EXPECT

func (m *MockStore) EXPECT() *MockStoreMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockStore) EnqueueFlush added in v0.0.17

func (m *MockStore) EnqueueFlush(arg0 context.Context, arg1 db.EnqueueFlushParams) (db.FlushCache, error)

EnqueueFlush mocks base method.

func (*MockStore) FindProviders added in v0.0.38

func (m *MockStore) FindProviders(arg0 context.Context, arg1 db.FindProvidersParams) ([]db.Provider, error)

FindProviders mocks base method.

func (*MockStore) FlushCache added in v0.0.17

func (m *MockStore) FlushCache(arg0 context.Context, arg1 db.FlushCacheParams) (db.FlushCache, error)

FlushCache mocks base method.

func (*MockStore) GetAccessTokenByEnrollmentNonce added in v0.0.39

func (m *MockStore) GetAccessTokenByEnrollmentNonce(arg0 context.Context, arg1 db.GetAccessTokenByEnrollmentNonceParams) (db.ProviderAccessToken, error)

GetAccessTokenByEnrollmentNonce mocks base method.

func (*MockStore) GetAccessTokenByProjectID

func (m *MockStore) GetAccessTokenByProjectID(arg0 context.Context, arg1 db.GetAccessTokenByProjectIDParams) (db.ProviderAccessToken, error)

GetAccessTokenByProjectID mocks base method.

func (*MockStore) GetAccessTokenByProvider

func (m *MockStore) GetAccessTokenByProvider(arg0 context.Context, arg1 string) ([]db.ProviderAccessToken, error)

GetAccessTokenByProvider mocks base method.

func (*MockStore) GetAccessTokenSinceDate

func (m *MockStore) GetAccessTokenSinceDate(arg0 context.Context, arg1 db.GetAccessTokenSinceDateParams) (db.ProviderAccessToken, error)

GetAccessTokenSinceDate mocks base method.

func (*MockStore) GetArtifactByID

func (m *MockStore) GetArtifactByID(arg0 context.Context, arg1 db.GetArtifactByIDParams) (db.Artifact, error)

GetArtifactByID mocks base method.

func (*MockStore) GetArtifactByName added in v0.0.22

func (m *MockStore) GetArtifactByName(arg0 context.Context, arg1 db.GetArtifactByNameParams) (db.Artifact, error)

GetArtifactByName mocks base method.

func (*MockStore) GetBundle added in v0.0.38

func (m *MockStore) GetBundle(arg0 context.Context, arg1 db.GetBundleParams) (db.Bundle, error)

GetBundle mocks base method.

func (*MockStore) GetChildrenProjects

func (m *MockStore) GetChildrenProjects(arg0 context.Context, arg1 uuid.UUID) ([]db.GetChildrenProjectsRow, error)

GetChildrenProjects mocks base method.

func (*MockStore) GetFeatureInProject

func (m *MockStore) GetFeatureInProject(arg0 context.Context, arg1 db.GetFeatureInProjectParams) (json.RawMessage, error)

GetFeatureInProject mocks base method.

func (*MockStore) GetIDByProfileEntityName added in v0.0.53

func (m *MockStore) GetIDByProfileEntityName(arg0 context.Context, arg1 db.GetIDByProfileEntityNameParams) (uuid.UUID, error)

GetIDByProfileEntityName mocks base method.

func (*MockStore) GetImmediateChildrenProjects added in v0.0.53

func (m *MockStore) GetImmediateChildrenProjects(arg0 context.Context, arg1 uuid.UUID) ([]db.Project, error)

GetImmediateChildrenProjects mocks base method.

func (*MockStore) GetInstallationIDByAppID added in v0.0.39

func (m *MockStore) GetInstallationIDByAppID(arg0 context.Context, arg1 int64) (db.ProviderGithubAppInstallation, error)

GetInstallationIDByAppID mocks base method.

func (*MockStore) GetInstallationIDByEnrollmentNonce added in v0.0.39

func (m *MockStore) GetInstallationIDByEnrollmentNonce(arg0 context.Context, arg1 db.GetInstallationIDByEnrollmentNonceParams) (db.ProviderGithubAppInstallation, error)

GetInstallationIDByEnrollmentNonce mocks base method.

func (*MockStore) GetInstallationIDByProviderID added in v0.0.37

func (m *MockStore) GetInstallationIDByProviderID(arg0 context.Context, arg1 uuid.NullUUID) (db.ProviderGithubAppInstallation, error)

GetInstallationIDByProviderID mocks base method.

func (*MockStore) GetInvitationByCode added in v0.0.53

func (m *MockStore) GetInvitationByCode(arg0 context.Context, arg1 string) (db.GetInvitationByCodeRow, error)

GetInvitationByCode mocks base method.

func (*MockStore) GetInvitationsByEmail added in v0.0.53

func (m *MockStore) GetInvitationsByEmail(arg0 context.Context, arg1 string) ([]db.GetInvitationsByEmailRow, error)

GetInvitationsByEmail mocks base method.

func (*MockStore) GetInvitationsByEmailAndProject added in v0.0.53

GetInvitationsByEmailAndProject mocks base method.

func (*MockStore) GetLatestEvalStateForRuleEntity added in v0.0.53

func (m *MockStore) GetLatestEvalStateForRuleEntity(arg0 context.Context, arg1 db.GetLatestEvalStateForRuleEntityParams) (db.EvaluationStatus, error)

GetLatestEvalStateForRuleEntity mocks base method.

func (*MockStore) GetParentProjects

func (m *MockStore) GetParentProjects(arg0 context.Context, arg1 uuid.UUID) ([]uuid.UUID, error)

GetParentProjects mocks base method.

func (*MockStore) GetParentProjectsUntil

func (m *MockStore) GetParentProjectsUntil(arg0 context.Context, arg1 db.GetParentProjectsUntilParams) ([]uuid.UUID, error)

GetParentProjectsUntil mocks base method.

func (*MockStore) GetProfileByID

func (m *MockStore) GetProfileByID(arg0 context.Context, arg1 db.GetProfileByIDParams) (db.Profile, error)

GetProfileByID mocks base method.

func (*MockStore) GetProfileByIDAndLock added in v0.0.16

func (m *MockStore) GetProfileByIDAndLock(arg0 context.Context, arg1 db.GetProfileByIDAndLockParams) (db.Profile, error)

GetProfileByIDAndLock mocks base method.

func (*MockStore) GetProfileByNameAndLock added in v0.0.16

func (m *MockStore) GetProfileByNameAndLock(arg0 context.Context, arg1 db.GetProfileByNameAndLockParams) (db.Profile, error)

GetProfileByNameAndLock mocks base method.

func (*MockStore) GetProfileByProjectAndID

func (m *MockStore) GetProfileByProjectAndID(arg0 context.Context, arg1 db.GetProfileByProjectAndIDParams) ([]db.GetProfileByProjectAndIDRow, error)

GetProfileByProjectAndID mocks base method.

func (*MockStore) GetProfileForEntity added in v0.0.16

func (m *MockStore) GetProfileForEntity(arg0 context.Context, arg1 db.GetProfileForEntityParams) (db.EntityProfile, error)

GetProfileForEntity mocks base method.

func (*MockStore) GetProfileStatusByIdAndProject

GetProfileStatusByIdAndProject mocks base method.

func (*MockStore) GetProfileStatusByNameAndProject

GetProfileStatusByNameAndProject mocks base method.

func (*MockStore) GetProfileStatusByProject

func (m *MockStore) GetProfileStatusByProject(arg0 context.Context, arg1 uuid.UUID) ([]db.GetProfileStatusByProjectRow, error)

GetProfileStatusByProject mocks base method.

func (*MockStore) GetProjectByID

func (m *MockStore) GetProjectByID(arg0 context.Context, arg1 uuid.UUID) (db.Project, error)

GetProjectByID mocks base method.

func (*MockStore) GetProjectByName

func (m *MockStore) GetProjectByName(arg0 context.Context, arg1 string) (db.Project, error)

GetProjectByName mocks base method.

func (*MockStore) GetProjectIDBySessionState added in v0.0.35

func (m *MockStore) GetProjectIDBySessionState(arg0 context.Context, arg1 string) (db.GetProjectIDBySessionStateRow, error)

GetProjectIDBySessionState mocks base method.

func (*MockStore) GetProviderByID

func (m *MockStore) GetProviderByID(arg0 context.Context, arg1 uuid.UUID) (db.Provider, error)

GetProviderByID mocks base method.

func (*MockStore) GetProviderByIDAndProject added in v0.0.48

func (m *MockStore) GetProviderByIDAndProject(arg0 context.Context, arg1 db.GetProviderByIDAndProjectParams) (db.Provider, error)

GetProviderByIDAndProject mocks base method.

func (*MockStore) GetProviderByName

func (m *MockStore) GetProviderByName(arg0 context.Context, arg1 db.GetProviderByNameParams) (db.Provider, error)

GetProviderByName mocks base method.

func (*MockStore) GetProviderWebhooks added in v0.0.48

func (m *MockStore) GetProviderWebhooks(arg0 context.Context, arg1 uuid.UUID) ([]db.GetProviderWebhooksRow, error)

GetProviderWebhooks mocks base method.

func (*MockStore) GetPullRequest

func (m *MockStore) GetPullRequest(arg0 context.Context, arg1 db.GetPullRequestParams) (db.PullRequest, error)

GetPullRequest mocks base method.

func (*MockStore) GetPullRequestByID added in v0.0.17

func (m *MockStore) GetPullRequestByID(arg0 context.Context, arg1 uuid.UUID) (db.PullRequest, error)

GetPullRequestByID mocks base method.

func (*MockStore) GetQuerierWithTransaction

func (m *MockStore) GetQuerierWithTransaction(arg0 *sql.Tx) db.ExtendQuerier

GetQuerierWithTransaction mocks base method.

func (*MockStore) GetRepositoryByID

func (m *MockStore) GetRepositoryByID(arg0 context.Context, arg1 uuid.UUID) (db.Repository, error)

GetRepositoryByID mocks base method.

func (*MockStore) GetRepositoryByIDAndProject

func (m *MockStore) GetRepositoryByIDAndProject(arg0 context.Context, arg1 db.GetRepositoryByIDAndProjectParams) (db.Repository, error)

GetRepositoryByIDAndProject mocks base method.

func (*MockStore) GetRepositoryByRepoID

func (m *MockStore) GetRepositoryByRepoID(arg0 context.Context, arg1 int64) (db.Repository, error)

GetRepositoryByRepoID mocks base method.

func (*MockStore) GetRepositoryByRepoName

func (m *MockStore) GetRepositoryByRepoName(arg0 context.Context, arg1 db.GetRepositoryByRepoNameParams) (db.Repository, error)

GetRepositoryByRepoName mocks base method.

func (*MockStore) GetRuleEvaluationByProfileIdAndRuleType

func (m *MockStore) GetRuleEvaluationByProfileIdAndRuleType(arg0 context.Context, arg1 uuid.UUID, arg2 db.NullEntities, arg3 sql.NullString, arg4 uuid.NullUUID, arg5 sql.NullString) (db.ListRuleEvaluationsByProfileIdRow, error)

GetRuleEvaluationByProfileIdAndRuleType mocks base method.

func (*MockStore) GetRuleInstancesForProfile added in v0.0.52

func (m *MockStore) GetRuleInstancesForProfile(arg0 context.Context, arg1 uuid.UUID) ([]db.RuleInstance, error)

GetRuleInstancesForProfile mocks base method.

func (*MockStore) GetRuleInstancesForProfileEntity added in v0.0.52

func (m *MockStore) GetRuleInstancesForProfileEntity(arg0 context.Context, arg1 db.GetRuleInstancesForProfileEntityParams) ([]db.RuleInstance, error)

GetRuleInstancesForProfileEntity mocks base method.

func (*MockStore) GetRuleTypeByID

func (m *MockStore) GetRuleTypeByID(arg0 context.Context, arg1 uuid.UUID) (db.RuleType, error)

GetRuleTypeByID mocks base method.

func (*MockStore) GetRuleTypeByName

func (m *MockStore) GetRuleTypeByName(arg0 context.Context, arg1 db.GetRuleTypeByNameParams) (db.RuleType, error)

GetRuleTypeByName mocks base method.

func (*MockStore) GetSubscriptionByProjectBundle added in v0.0.37

func (m *MockStore) GetSubscriptionByProjectBundle(arg0 context.Context, arg1 db.GetSubscriptionByProjectBundleParams) (db.Subscription, error)

GetSubscriptionByProjectBundle mocks base method.

func (*MockStore) GetUnclaimedInstallationsByUser added in v0.0.40

func (m *MockStore) GetUnclaimedInstallationsByUser(arg0 context.Context, arg1 sql.NullString) ([]db.ProviderGithubAppInstallation, error)

GetUnclaimedInstallationsByUser mocks base method.

func (*MockStore) GetUserByID

func (m *MockStore) GetUserByID(arg0 context.Context, arg1 int32) (db.User, error)

GetUserByID mocks base method.

func (*MockStore) GetUserBySubject

func (m *MockStore) GetUserBySubject(arg0 context.Context, arg1 string) (db.User, error)

GetUserBySubject mocks base method.

func (*MockStore) GlobalListProviders

func (m *MockStore) GlobalListProviders(arg0 context.Context) ([]db.Provider, error)

GlobalListProviders mocks base method.

func (*MockStore) GlobalListProvidersByClass added in v0.0.38

func (m *MockStore) GlobalListProvidersByClass(arg0 context.Context, arg1 db.ProviderClass) ([]db.Provider, error)

GlobalListProvidersByClass mocks base method.

func (*MockStore) InsertEvaluationRuleEntity added in v0.0.53

func (m *MockStore) InsertEvaluationRuleEntity(arg0 context.Context, arg1 db.InsertEvaluationRuleEntityParams) (uuid.UUID, error)

InsertEvaluationRuleEntity mocks base method.

func (*MockStore) InsertEvaluationStatus added in v0.0.53

func (m *MockStore) InsertEvaluationStatus(arg0 context.Context, arg1 db.InsertEvaluationStatusParams) (uuid.UUID, error)

InsertEvaluationStatus mocks base method.

func (*MockStore) ListArtifactsByRepoID

func (m *MockStore) ListArtifactsByRepoID(arg0 context.Context, arg1 uuid.NullUUID) ([]db.Artifact, error)

ListArtifactsByRepoID mocks base method.

func (*MockStore) ListFlushCache added in v0.0.17

func (m *MockStore) ListFlushCache(arg0 context.Context) ([]db.FlushCache, error)

ListFlushCache mocks base method.

func (*MockStore) ListInvitationsForProject added in v0.0.52

func (m *MockStore) ListInvitationsForProject(arg0 context.Context, arg1 uuid.UUID) ([]db.ListInvitationsForProjectRow, error)

ListInvitationsForProject mocks base method.

func (*MockStore) ListNonOrgProjects added in v0.0.35

func (m *MockStore) ListNonOrgProjects(arg0 context.Context) ([]db.Project, error)

ListNonOrgProjects mocks base method.

func (*MockStore) ListOldOrgProjects added in v0.0.35

func (m *MockStore) ListOldOrgProjects(arg0 context.Context) ([]db.Project, error)

ListOldOrgProjects mocks base method.

func (*MockStore) ListOldestRuleEvaluationsByRepositoryId added in v0.0.52

func (m *MockStore) ListOldestRuleEvaluationsByRepositoryId(arg0 context.Context, arg1 []uuid.UUID) ([]db.ListOldestRuleEvaluationsByRepositoryIdRow, error)

ListOldestRuleEvaluationsByRepositoryId mocks base method.

func (*MockStore) ListProfilesByProjectID

func (m *MockStore) ListProfilesByProjectID(arg0 context.Context, arg1 uuid.UUID) ([]db.ListProfilesByProjectIDRow, error)

ListProfilesByProjectID mocks base method.

func (*MockStore) ListProfilesByProjectIDAndLabel added in v0.0.38

ListProfilesByProjectIDAndLabel mocks base method.

func (*MockStore) ListProfilesInstantiatingRuleType

func (m *MockStore) ListProfilesInstantiatingRuleType(arg0 context.Context, arg1 uuid.UUID) ([]db.ListProfilesInstantiatingRuleTypeRow, error)

ListProfilesInstantiatingRuleType mocks base method.

func (*MockStore) ListProvidersByProjectID

func (m *MockStore) ListProvidersByProjectID(arg0 context.Context, arg1 []uuid.UUID) ([]db.Provider, error)

ListProvidersByProjectID mocks base method.

func (*MockStore) ListProvidersByProjectIDPaginated added in v0.0.30

func (m *MockStore) ListProvidersByProjectIDPaginated(arg0 context.Context, arg1 db.ListProvidersByProjectIDPaginatedParams) ([]db.Provider, error)

ListProvidersByProjectIDPaginated mocks base method.

func (*MockStore) ListRegisteredRepositoriesByProjectIDAndProvider

func (m *MockStore) ListRegisteredRepositoriesByProjectIDAndProvider(arg0 context.Context, arg1 db.ListRegisteredRepositoriesByProjectIDAndProviderParams) ([]db.Repository, error)

ListRegisteredRepositoriesByProjectIDAndProvider mocks base method.

func (*MockStore) ListRepositoriesAfterID added in v0.0.52

func (m *MockStore) ListRepositoriesAfterID(arg0 context.Context, arg1 db.ListRepositoriesAfterIDParams) ([]db.Repository, error)

ListRepositoriesAfterID mocks base method.

func (*MockStore) ListRepositoriesByProjectID

func (m *MockStore) ListRepositoriesByProjectID(arg0 context.Context, arg1 db.ListRepositoriesByProjectIDParams) ([]db.Repository, error)

ListRepositoriesByProjectID mocks base method.

func (*MockStore) ListRuleEvaluationsByProfileId

ListRuleEvaluationsByProfileId mocks base method.

func (*MockStore) ListRuleTypesByProject added in v0.0.39

func (m *MockStore) ListRuleTypesByProject(arg0 context.Context, arg1 uuid.UUID) ([]db.RuleType, error)

ListRuleTypesByProject mocks base method.

func (*MockStore) ListTokensToMigrate added in v0.0.52

func (m *MockStore) ListTokensToMigrate(arg0 context.Context, arg1 db.ListTokensToMigrateParams) ([]db.ProviderAccessToken, error)

ListTokensToMigrate mocks base method.

func (*MockStore) ListUsers

func (m *MockStore) ListUsers(arg0 context.Context, arg1 db.ListUsersParams) ([]db.User, error)

ListUsers mocks base method.

func (*MockStore) LockIfThresholdNotExceeded added in v0.0.17

func (m *MockStore) LockIfThresholdNotExceeded(arg0 context.Context, arg1 db.LockIfThresholdNotExceededParams) (db.EntityExecutionLock, error)

LockIfThresholdNotExceeded mocks base method.

func (*MockStore) OrphanProject added in v0.0.35

func (m *MockStore) OrphanProject(arg0 context.Context, arg1 db.OrphanProjectParams) (db.Project, error)

OrphanProject mocks base method.

func (*MockStore) ReleaseLock added in v0.0.17

func (m *MockStore) ReleaseLock(arg0 context.Context, arg1 db.ReleaseLockParams) error

ReleaseLock mocks base method.

func (*MockStore) RepositoryExistsAfterID added in v0.0.52

func (m *MockStore) RepositoryExistsAfterID(arg0 context.Context, arg1 uuid.UUID) (bool, error)

RepositoryExistsAfterID mocks base method.

func (*MockStore) Rollback

func (m *MockStore) Rollback(arg0 *sql.Tx) error

Rollback mocks base method.

func (*MockStore) SetCurrentVersion added in v0.0.37

func (m *MockStore) SetCurrentVersion(arg0 context.Context, arg1 db.SetCurrentVersionParams) error

SetCurrentVersion mocks base method.

func (*MockStore) UpdateEncryptedSecret added in v0.0.52

func (m *MockStore) UpdateEncryptedSecret(arg0 context.Context, arg1 db.UpdateEncryptedSecretParams) error

UpdateEncryptedSecret mocks base method.

func (*MockStore) UpdateEvaluationTimes added in v0.0.53

func (m *MockStore) UpdateEvaluationTimes(arg0 context.Context, arg1 db.UpdateEvaluationTimesParams) error

UpdateEvaluationTimes mocks base method.

func (*MockStore) UpdateInvitation added in v0.0.53

func (m *MockStore) UpdateInvitation(arg0 context.Context, arg1 string) (db.UserInvite, error)

UpdateInvitation mocks base method.

func (*MockStore) UpdateLease added in v0.0.17

func (m *MockStore) UpdateLease(arg0 context.Context, arg1 db.UpdateLeaseParams) error

UpdateLease mocks base method.

func (*MockStore) UpdateProfile added in v0.0.16

func (m *MockStore) UpdateProfile(arg0 context.Context, arg1 db.UpdateProfileParams) (db.Profile, error)

UpdateProfile mocks base method.

func (*MockStore) UpdateProjectMeta added in v0.0.35

func (m *MockStore) UpdateProjectMeta(arg0 context.Context, arg1 db.UpdateProjectMetaParams) (db.Project, error)

UpdateProjectMeta mocks base method.

func (*MockStore) UpdateProvider added in v0.0.35

func (m *MockStore) UpdateProvider(arg0 context.Context, arg1 db.UpdateProviderParams) error

UpdateProvider mocks base method.

func (*MockStore) UpdateReminderLastSentById added in v0.0.52

func (m *MockStore) UpdateReminderLastSentById(arg0 context.Context, arg1 uuid.UUID) error

UpdateReminderLastSentById mocks base method.

func (*MockStore) UpdateRuleType

func (m *MockStore) UpdateRuleType(arg0 context.Context, arg1 db.UpdateRuleTypeParams) (db.RuleType, error)

UpdateRuleType mocks base method.

func (*MockStore) UpsertAccessToken added in v0.0.33

func (m *MockStore) UpsertAccessToken(arg0 context.Context, arg1 db.UpsertAccessTokenParams) (db.ProviderAccessToken, error)

UpsertAccessToken mocks base method.

func (*MockStore) UpsertArtifact

func (m *MockStore) UpsertArtifact(arg0 context.Context, arg1 db.UpsertArtifactParams) (db.Artifact, error)

UpsertArtifact mocks base method.

func (*MockStore) UpsertBundle added in v0.0.37

func (m *MockStore) UpsertBundle(arg0 context.Context, arg1 db.UpsertBundleParams) error

UpsertBundle mocks base method.

func (*MockStore) UpsertInstallationID added in v0.0.38

UpsertInstallationID mocks base method.

func (*MockStore) UpsertLatestEvaluationStatus added in v0.0.53

func (m *MockStore) UpsertLatestEvaluationStatus(arg0 context.Context, arg1 db.UpsertLatestEvaluationStatusParams) error

UpsertLatestEvaluationStatus mocks base method.

func (*MockStore) UpsertProfileForEntity added in v0.0.16

func (m *MockStore) UpsertProfileForEntity(arg0 context.Context, arg1 db.UpsertProfileForEntityParams) (db.EntityProfile, error)

UpsertProfileForEntity mocks base method.

func (*MockStore) UpsertPullRequest

func (m *MockStore) UpsertPullRequest(arg0 context.Context, arg1 db.UpsertPullRequestParams) (db.PullRequest, error)

UpsertPullRequest mocks base method.

func (*MockStore) UpsertRuleDetailsAlert

func (m *MockStore) UpsertRuleDetailsAlert(arg0 context.Context, arg1 db.UpsertRuleDetailsAlertParams) (uuid.UUID, error)

UpsertRuleDetailsAlert mocks base method.

func (*MockStore) UpsertRuleDetailsEval

func (m *MockStore) UpsertRuleDetailsEval(arg0 context.Context, arg1 db.UpsertRuleDetailsEvalParams) (uuid.UUID, error)

UpsertRuleDetailsEval mocks base method.

func (*MockStore) UpsertRuleDetailsRemediate

func (m *MockStore) UpsertRuleDetailsRemediate(arg0 context.Context, arg1 db.UpsertRuleDetailsRemediateParams) (uuid.UUID, error)

UpsertRuleDetailsRemediate mocks base method.

func (*MockStore) UpsertRuleEvaluations

func (m *MockStore) UpsertRuleEvaluations(arg0 context.Context, arg1 db.UpsertRuleEvaluationsParams) (uuid.UUID, error)

UpsertRuleEvaluations mocks base method.

func (*MockStore) UpsertRuleInstance added in v0.0.52

func (m *MockStore) UpsertRuleInstance(arg0 context.Context, arg1 db.UpsertRuleInstanceParams) (uuid.UUID, error)

UpsertRuleInstance mocks base method.

func (*MockStore) UpsertRuleInstantiation

func (m *MockStore) UpsertRuleInstantiation(arg0 context.Context, arg1 db.UpsertRuleInstantiationParams) (db.EntityProfileRule, error)

UpsertRuleInstantiation mocks base method.

type MockStoreMockRecorder

type MockStoreMockRecorder struct {
	// contains filtered or unexported fields
}

MockStoreMockRecorder is the mock recorder for MockStore.

func (*MockStoreMockRecorder) BeginTransaction

func (mr *MockStoreMockRecorder) BeginTransaction() *gomock.Call

BeginTransaction indicates an expected call of BeginTransaction.

func (*MockStoreMockRecorder) CheckHealth

func (mr *MockStoreMockRecorder) CheckHealth() *gomock.Call

CheckHealth indicates an expected call of CheckHealth.

func (*MockStoreMockRecorder) Commit

func (mr *MockStoreMockRecorder) Commit(arg0 any) *gomock.Call

Commit indicates an expected call of Commit.

func (*MockStoreMockRecorder) CountProfilesByEntityType

func (mr *MockStoreMockRecorder) CountProfilesByEntityType(arg0 any) *gomock.Call

CountProfilesByEntityType indicates an expected call of CountProfilesByEntityType.

func (*MockStoreMockRecorder) CountProfilesByName added in v0.0.20

func (mr *MockStoreMockRecorder) CountProfilesByName(arg0, arg1 any) *gomock.Call

CountProfilesByName indicates an expected call of CountProfilesByName.

func (*MockStoreMockRecorder) CountRepositories added in v0.0.16

func (mr *MockStoreMockRecorder) CountRepositories(arg0 any) *gomock.Call

CountRepositories indicates an expected call of CountRepositories.

func (*MockStoreMockRecorder) CountUsers

func (mr *MockStoreMockRecorder) CountUsers(arg0 any) *gomock.Call

CountUsers indicates an expected call of CountUsers.

func (*MockStoreMockRecorder) CreateInvitation added in v0.0.53

func (mr *MockStoreMockRecorder) CreateInvitation(arg0, arg1 any) *gomock.Call

CreateInvitation indicates an expected call of CreateInvitation.

func (*MockStoreMockRecorder) CreateProfile

func (mr *MockStoreMockRecorder) CreateProfile(arg0, arg1 any) *gomock.Call

CreateProfile indicates an expected call of CreateProfile.

func (*MockStoreMockRecorder) CreateProfileForEntity

func (mr *MockStoreMockRecorder) CreateProfileForEntity(arg0, arg1 any) *gomock.Call

CreateProfileForEntity indicates an expected call of CreateProfileForEntity.

func (*MockStoreMockRecorder) CreateProject

func (mr *MockStoreMockRecorder) CreateProject(arg0, arg1 any) *gomock.Call

CreateProject indicates an expected call of CreateProject.

func (*MockStoreMockRecorder) CreateProjectWithID added in v0.0.27

func (mr *MockStoreMockRecorder) CreateProjectWithID(arg0, arg1 any) *gomock.Call

CreateProjectWithID indicates an expected call of CreateProjectWithID.

func (*MockStoreMockRecorder) CreateProvider

func (mr *MockStoreMockRecorder) CreateProvider(arg0, arg1 any) *gomock.Call

CreateProvider indicates an expected call of CreateProvider.

func (*MockStoreMockRecorder) CreatePullRequest

func (mr *MockStoreMockRecorder) CreatePullRequest(arg0, arg1 any) *gomock.Call

CreatePullRequest indicates an expected call of CreatePullRequest.

func (*MockStoreMockRecorder) CreateRepository

func (mr *MockStoreMockRecorder) CreateRepository(arg0, arg1 any) *gomock.Call

CreateRepository indicates an expected call of CreateRepository.

func (*MockStoreMockRecorder) CreateRuleType

func (mr *MockStoreMockRecorder) CreateRuleType(arg0, arg1 any) *gomock.Call

CreateRuleType indicates an expected call of CreateRuleType.

func (*MockStoreMockRecorder) CreateSessionState

func (mr *MockStoreMockRecorder) CreateSessionState(arg0, arg1 any) *gomock.Call

CreateSessionState indicates an expected call of CreateSessionState.

func (*MockStoreMockRecorder) CreateSubscription added in v0.0.37

func (mr *MockStoreMockRecorder) CreateSubscription(arg0, arg1 any) *gomock.Call

CreateSubscription indicates an expected call of CreateSubscription.

func (*MockStoreMockRecorder) CreateUser

func (mr *MockStoreMockRecorder) CreateUser(arg0, arg1 any) *gomock.Call

CreateUser indicates an expected call of CreateUser.

func (*MockStoreMockRecorder) DeleteArtifact

func (mr *MockStoreMockRecorder) DeleteArtifact(arg0, arg1 any) *gomock.Call

DeleteArtifact indicates an expected call of DeleteArtifact.

func (*MockStoreMockRecorder) DeleteExpiredSessionStates

func (mr *MockStoreMockRecorder) DeleteExpiredSessionStates(arg0 any) *gomock.Call

DeleteExpiredSessionStates indicates an expected call of DeleteExpiredSessionStates.

func (*MockStoreMockRecorder) DeleteInstallationIDByAppID added in v0.0.39

func (mr *MockStoreMockRecorder) DeleteInstallationIDByAppID(arg0, arg1 any) *gomock.Call

DeleteInstallationIDByAppID indicates an expected call of DeleteInstallationIDByAppID.

func (*MockStoreMockRecorder) DeleteInvitation added in v0.0.53

func (mr *MockStoreMockRecorder) DeleteInvitation(arg0, arg1 any) *gomock.Call

DeleteInvitation indicates an expected call of DeleteInvitation.

func (*MockStoreMockRecorder) DeleteNonUpdatedRules added in v0.0.52

func (mr *MockStoreMockRecorder) DeleteNonUpdatedRules(arg0, arg1 any) *gomock.Call

DeleteNonUpdatedRules indicates an expected call of DeleteNonUpdatedRules.

func (*MockStoreMockRecorder) DeleteProfile

func (mr *MockStoreMockRecorder) DeleteProfile(arg0, arg1 any) *gomock.Call

DeleteProfile indicates an expected call of DeleteProfile.

func (*MockStoreMockRecorder) DeleteProfileForEntity added in v0.0.16

func (mr *MockStoreMockRecorder) DeleteProfileForEntity(arg0, arg1 any) *gomock.Call

DeleteProfileForEntity indicates an expected call of DeleteProfileForEntity.

func (*MockStoreMockRecorder) DeleteProject

func (mr *MockStoreMockRecorder) DeleteProject(arg0, arg1 any) *gomock.Call

DeleteProject indicates an expected call of DeleteProject.

func (*MockStoreMockRecorder) DeleteProvider

func (mr *MockStoreMockRecorder) DeleteProvider(arg0, arg1 any) *gomock.Call

DeleteProvider indicates an expected call of DeleteProvider.

func (*MockStoreMockRecorder) DeletePullRequest

func (mr *MockStoreMockRecorder) DeletePullRequest(arg0, arg1 any) *gomock.Call

DeletePullRequest indicates an expected call of DeletePullRequest.

func (*MockStoreMockRecorder) DeleteRepository

func (mr *MockStoreMockRecorder) DeleteRepository(arg0, arg1 any) *gomock.Call

DeleteRepository indicates an expected call of DeleteRepository.

func (*MockStoreMockRecorder) DeleteRuleInstantiation added in v0.0.16

func (mr *MockStoreMockRecorder) DeleteRuleInstantiation(arg0, arg1 any) *gomock.Call

DeleteRuleInstantiation indicates an expected call of DeleteRuleInstantiation.

func (*MockStoreMockRecorder) DeleteRuleStatusesForProfileAndRuleType added in v0.0.16

func (mr *MockStoreMockRecorder) DeleteRuleStatusesForProfileAndRuleType(arg0, arg1 any) *gomock.Call

DeleteRuleStatusesForProfileAndRuleType indicates an expected call of DeleteRuleStatusesForProfileAndRuleType.

func (*MockStoreMockRecorder) DeleteRuleType

func (mr *MockStoreMockRecorder) DeleteRuleType(arg0, arg1 any) *gomock.Call

DeleteRuleType indicates an expected call of DeleteRuleType.

func (*MockStoreMockRecorder) DeleteSessionStateByProjectID

func (mr *MockStoreMockRecorder) DeleteSessionStateByProjectID(arg0, arg1 any) *gomock.Call

DeleteSessionStateByProjectID indicates an expected call of DeleteSessionStateByProjectID.

func (*MockStoreMockRecorder) DeleteUser

func (mr *MockStoreMockRecorder) DeleteUser(arg0, arg1 any) *gomock.Call

DeleteUser indicates an expected call of DeleteUser.

func (*MockStoreMockRecorder) EnqueueFlush added in v0.0.17

func (mr *MockStoreMockRecorder) EnqueueFlush(arg0, arg1 any) *gomock.Call

EnqueueFlush indicates an expected call of EnqueueFlush.

func (*MockStoreMockRecorder) FindProviders added in v0.0.38

func (mr *MockStoreMockRecorder) FindProviders(arg0, arg1 any) *gomock.Call

FindProviders indicates an expected call of FindProviders.

func (*MockStoreMockRecorder) FlushCache added in v0.0.17

func (mr *MockStoreMockRecorder) FlushCache(arg0, arg1 any) *gomock.Call

FlushCache indicates an expected call of FlushCache.

func (*MockStoreMockRecorder) GetAccessTokenByEnrollmentNonce added in v0.0.39

func (mr *MockStoreMockRecorder) GetAccessTokenByEnrollmentNonce(arg0, arg1 any) *gomock.Call

GetAccessTokenByEnrollmentNonce indicates an expected call of GetAccessTokenByEnrollmentNonce.

func (*MockStoreMockRecorder) GetAccessTokenByProjectID

func (mr *MockStoreMockRecorder) GetAccessTokenByProjectID(arg0, arg1 any) *gomock.Call

GetAccessTokenByProjectID indicates an expected call of GetAccessTokenByProjectID.

func (*MockStoreMockRecorder) GetAccessTokenByProvider

func (mr *MockStoreMockRecorder) GetAccessTokenByProvider(arg0, arg1 any) *gomock.Call

GetAccessTokenByProvider indicates an expected call of GetAccessTokenByProvider.

func (*MockStoreMockRecorder) GetAccessTokenSinceDate

func (mr *MockStoreMockRecorder) GetAccessTokenSinceDate(arg0, arg1 any) *gomock.Call

GetAccessTokenSinceDate indicates an expected call of GetAccessTokenSinceDate.

func (*MockStoreMockRecorder) GetArtifactByID

func (mr *MockStoreMockRecorder) GetArtifactByID(arg0, arg1 any) *gomock.Call

GetArtifactByID indicates an expected call of GetArtifactByID.

func (*MockStoreMockRecorder) GetArtifactByName added in v0.0.22

func (mr *MockStoreMockRecorder) GetArtifactByName(arg0, arg1 any) *gomock.Call

GetArtifactByName indicates an expected call of GetArtifactByName.

func (*MockStoreMockRecorder) GetBundle added in v0.0.38

func (mr *MockStoreMockRecorder) GetBundle(arg0, arg1 any) *gomock.Call

GetBundle indicates an expected call of GetBundle.

func (*MockStoreMockRecorder) GetChildrenProjects

func (mr *MockStoreMockRecorder) GetChildrenProjects(arg0, arg1 any) *gomock.Call

GetChildrenProjects indicates an expected call of GetChildrenProjects.

func (*MockStoreMockRecorder) GetFeatureInProject

func (mr *MockStoreMockRecorder) GetFeatureInProject(arg0, arg1 any) *gomock.Call

GetFeatureInProject indicates an expected call of GetFeatureInProject.

func (*MockStoreMockRecorder) GetIDByProfileEntityName added in v0.0.53

func (mr *MockStoreMockRecorder) GetIDByProfileEntityName(arg0, arg1 any) *gomock.Call

GetIDByProfileEntityName indicates an expected call of GetIDByProfileEntityName.

func (*MockStoreMockRecorder) GetImmediateChildrenProjects added in v0.0.53

func (mr *MockStoreMockRecorder) GetImmediateChildrenProjects(arg0, arg1 any) *gomock.Call

GetImmediateChildrenProjects indicates an expected call of GetImmediateChildrenProjects.

func (*MockStoreMockRecorder) GetInstallationIDByAppID added in v0.0.39

func (mr *MockStoreMockRecorder) GetInstallationIDByAppID(arg0, arg1 any) *gomock.Call

GetInstallationIDByAppID indicates an expected call of GetInstallationIDByAppID.

func (*MockStoreMockRecorder) GetInstallationIDByEnrollmentNonce added in v0.0.39

func (mr *MockStoreMockRecorder) GetInstallationIDByEnrollmentNonce(arg0, arg1 any) *gomock.Call

GetInstallationIDByEnrollmentNonce indicates an expected call of GetInstallationIDByEnrollmentNonce.

func (*MockStoreMockRecorder) GetInstallationIDByProviderID added in v0.0.37

func (mr *MockStoreMockRecorder) GetInstallationIDByProviderID(arg0, arg1 any) *gomock.Call

GetInstallationIDByProviderID indicates an expected call of GetInstallationIDByProviderID.

func (*MockStoreMockRecorder) GetInvitationByCode added in v0.0.53

func (mr *MockStoreMockRecorder) GetInvitationByCode(arg0, arg1 any) *gomock.Call

GetInvitationByCode indicates an expected call of GetInvitationByCode.

func (*MockStoreMockRecorder) GetInvitationsByEmail added in v0.0.53

func (mr *MockStoreMockRecorder) GetInvitationsByEmail(arg0, arg1 any) *gomock.Call

GetInvitationsByEmail indicates an expected call of GetInvitationsByEmail.

func (*MockStoreMockRecorder) GetInvitationsByEmailAndProject added in v0.0.53

func (mr *MockStoreMockRecorder) GetInvitationsByEmailAndProject(arg0, arg1 any) *gomock.Call

GetInvitationsByEmailAndProject indicates an expected call of GetInvitationsByEmailAndProject.

func (*MockStoreMockRecorder) GetLatestEvalStateForRuleEntity added in v0.0.53

func (mr *MockStoreMockRecorder) GetLatestEvalStateForRuleEntity(arg0, arg1 any) *gomock.Call

GetLatestEvalStateForRuleEntity indicates an expected call of GetLatestEvalStateForRuleEntity.

func (*MockStoreMockRecorder) GetParentProjects

func (mr *MockStoreMockRecorder) GetParentProjects(arg0, arg1 any) *gomock.Call

GetParentProjects indicates an expected call of GetParentProjects.

func (*MockStoreMockRecorder) GetParentProjectsUntil

func (mr *MockStoreMockRecorder) GetParentProjectsUntil(arg0, arg1 any) *gomock.Call

GetParentProjectsUntil indicates an expected call of GetParentProjectsUntil.

func (*MockStoreMockRecorder) GetProfileByID

func (mr *MockStoreMockRecorder) GetProfileByID(arg0, arg1 any) *gomock.Call

GetProfileByID indicates an expected call of GetProfileByID.

func (*MockStoreMockRecorder) GetProfileByIDAndLock added in v0.0.16

func (mr *MockStoreMockRecorder) GetProfileByIDAndLock(arg0, arg1 any) *gomock.Call

GetProfileByIDAndLock indicates an expected call of GetProfileByIDAndLock.

func (*MockStoreMockRecorder) GetProfileByNameAndLock added in v0.0.16

func (mr *MockStoreMockRecorder) GetProfileByNameAndLock(arg0, arg1 any) *gomock.Call

GetProfileByNameAndLock indicates an expected call of GetProfileByNameAndLock.

func (*MockStoreMockRecorder) GetProfileByProjectAndID

func (mr *MockStoreMockRecorder) GetProfileByProjectAndID(arg0, arg1 any) *gomock.Call

GetProfileByProjectAndID indicates an expected call of GetProfileByProjectAndID.

func (*MockStoreMockRecorder) GetProfileForEntity added in v0.0.16

func (mr *MockStoreMockRecorder) GetProfileForEntity(arg0, arg1 any) *gomock.Call

GetProfileForEntity indicates an expected call of GetProfileForEntity.

func (*MockStoreMockRecorder) GetProfileStatusByIdAndProject

func (mr *MockStoreMockRecorder) GetProfileStatusByIdAndProject(arg0, arg1 any) *gomock.Call

GetProfileStatusByIdAndProject indicates an expected call of GetProfileStatusByIdAndProject.

func (*MockStoreMockRecorder) GetProfileStatusByNameAndProject

func (mr *MockStoreMockRecorder) GetProfileStatusByNameAndProject(arg0, arg1 any) *gomock.Call

GetProfileStatusByNameAndProject indicates an expected call of GetProfileStatusByNameAndProject.

func (*MockStoreMockRecorder) GetProfileStatusByProject

func (mr *MockStoreMockRecorder) GetProfileStatusByProject(arg0, arg1 any) *gomock.Call

GetProfileStatusByProject indicates an expected call of GetProfileStatusByProject.

func (*MockStoreMockRecorder) GetProjectByID

func (mr *MockStoreMockRecorder) GetProjectByID(arg0, arg1 any) *gomock.Call

GetProjectByID indicates an expected call of GetProjectByID.

func (*MockStoreMockRecorder) GetProjectByName

func (mr *MockStoreMockRecorder) GetProjectByName(arg0, arg1 any) *gomock.Call

GetProjectByName indicates an expected call of GetProjectByName.

func (*MockStoreMockRecorder) GetProjectIDBySessionState added in v0.0.35

func (mr *MockStoreMockRecorder) GetProjectIDBySessionState(arg0, arg1 any) *gomock.Call

GetProjectIDBySessionState indicates an expected call of GetProjectIDBySessionState.

func (*MockStoreMockRecorder) GetProviderByID

func (mr *MockStoreMockRecorder) GetProviderByID(arg0, arg1 any) *gomock.Call

GetProviderByID indicates an expected call of GetProviderByID.

func (*MockStoreMockRecorder) GetProviderByIDAndProject added in v0.0.48

func (mr *MockStoreMockRecorder) GetProviderByIDAndProject(arg0, arg1 any) *gomock.Call

GetProviderByIDAndProject indicates an expected call of GetProviderByIDAndProject.

func (*MockStoreMockRecorder) GetProviderByName

func (mr *MockStoreMockRecorder) GetProviderByName(arg0, arg1 any) *gomock.Call

GetProviderByName indicates an expected call of GetProviderByName.

func (*MockStoreMockRecorder) GetProviderWebhooks added in v0.0.48

func (mr *MockStoreMockRecorder) GetProviderWebhooks(arg0, arg1 any) *gomock.Call

GetProviderWebhooks indicates an expected call of GetProviderWebhooks.

func (*MockStoreMockRecorder) GetPullRequest

func (mr *MockStoreMockRecorder) GetPullRequest(arg0, arg1 any) *gomock.Call

GetPullRequest indicates an expected call of GetPullRequest.

func (*MockStoreMockRecorder) GetPullRequestByID added in v0.0.17

func (mr *MockStoreMockRecorder) GetPullRequestByID(arg0, arg1 any) *gomock.Call

GetPullRequestByID indicates an expected call of GetPullRequestByID.

func (*MockStoreMockRecorder) GetQuerierWithTransaction

func (mr *MockStoreMockRecorder) GetQuerierWithTransaction(arg0 any) *gomock.Call

GetQuerierWithTransaction indicates an expected call of GetQuerierWithTransaction.

func (*MockStoreMockRecorder) GetRepositoryByID

func (mr *MockStoreMockRecorder) GetRepositoryByID(arg0, arg1 any) *gomock.Call

GetRepositoryByID indicates an expected call of GetRepositoryByID.

func (*MockStoreMockRecorder) GetRepositoryByIDAndProject

func (mr *MockStoreMockRecorder) GetRepositoryByIDAndProject(arg0, arg1 any) *gomock.Call

GetRepositoryByIDAndProject indicates an expected call of GetRepositoryByIDAndProject.

func (*MockStoreMockRecorder) GetRepositoryByRepoID

func (mr *MockStoreMockRecorder) GetRepositoryByRepoID(arg0, arg1 any) *gomock.Call

GetRepositoryByRepoID indicates an expected call of GetRepositoryByRepoID.

func (*MockStoreMockRecorder) GetRepositoryByRepoName

func (mr *MockStoreMockRecorder) GetRepositoryByRepoName(arg0, arg1 any) *gomock.Call

GetRepositoryByRepoName indicates an expected call of GetRepositoryByRepoName.

func (*MockStoreMockRecorder) GetRuleEvaluationByProfileIdAndRuleType

func (mr *MockStoreMockRecorder) GetRuleEvaluationByProfileIdAndRuleType(arg0, arg1, arg2, arg3, arg4, arg5 any) *gomock.Call

GetRuleEvaluationByProfileIdAndRuleType indicates an expected call of GetRuleEvaluationByProfileIdAndRuleType.

func (*MockStoreMockRecorder) GetRuleInstancesForProfile added in v0.0.52

func (mr *MockStoreMockRecorder) GetRuleInstancesForProfile(arg0, arg1 any) *gomock.Call

GetRuleInstancesForProfile indicates an expected call of GetRuleInstancesForProfile.

func (*MockStoreMockRecorder) GetRuleInstancesForProfileEntity added in v0.0.52

func (mr *MockStoreMockRecorder) GetRuleInstancesForProfileEntity(arg0, arg1 any) *gomock.Call

GetRuleInstancesForProfileEntity indicates an expected call of GetRuleInstancesForProfileEntity.

func (*MockStoreMockRecorder) GetRuleTypeByID

func (mr *MockStoreMockRecorder) GetRuleTypeByID(arg0, arg1 any) *gomock.Call

GetRuleTypeByID indicates an expected call of GetRuleTypeByID.

func (*MockStoreMockRecorder) GetRuleTypeByName

func (mr *MockStoreMockRecorder) GetRuleTypeByName(arg0, arg1 any) *gomock.Call

GetRuleTypeByName indicates an expected call of GetRuleTypeByName.

func (*MockStoreMockRecorder) GetSubscriptionByProjectBundle added in v0.0.37

func (mr *MockStoreMockRecorder) GetSubscriptionByProjectBundle(arg0, arg1 any) *gomock.Call

GetSubscriptionByProjectBundle indicates an expected call of GetSubscriptionByProjectBundle.

func (*MockStoreMockRecorder) GetUnclaimedInstallationsByUser added in v0.0.40

func (mr *MockStoreMockRecorder) GetUnclaimedInstallationsByUser(arg0, arg1 any) *gomock.Call

GetUnclaimedInstallationsByUser indicates an expected call of GetUnclaimedInstallationsByUser.

func (*MockStoreMockRecorder) GetUserByID

func (mr *MockStoreMockRecorder) GetUserByID(arg0, arg1 any) *gomock.Call

GetUserByID indicates an expected call of GetUserByID.

func (*MockStoreMockRecorder) GetUserBySubject

func (mr *MockStoreMockRecorder) GetUserBySubject(arg0, arg1 any) *gomock.Call

GetUserBySubject indicates an expected call of GetUserBySubject.

func (*MockStoreMockRecorder) GlobalListProviders

func (mr *MockStoreMockRecorder) GlobalListProviders(arg0 any) *gomock.Call

GlobalListProviders indicates an expected call of GlobalListProviders.

func (*MockStoreMockRecorder) GlobalListProvidersByClass added in v0.0.38

func (mr *MockStoreMockRecorder) GlobalListProvidersByClass(arg0, arg1 any) *gomock.Call

GlobalListProvidersByClass indicates an expected call of GlobalListProvidersByClass.

func (*MockStoreMockRecorder) InsertEvaluationRuleEntity added in v0.0.53

func (mr *MockStoreMockRecorder) InsertEvaluationRuleEntity(arg0, arg1 any) *gomock.Call

InsertEvaluationRuleEntity indicates an expected call of InsertEvaluationRuleEntity.

func (*MockStoreMockRecorder) InsertEvaluationStatus added in v0.0.53

func (mr *MockStoreMockRecorder) InsertEvaluationStatus(arg0, arg1 any) *gomock.Call

InsertEvaluationStatus indicates an expected call of InsertEvaluationStatus.

func (*MockStoreMockRecorder) ListArtifactsByRepoID

func (mr *MockStoreMockRecorder) ListArtifactsByRepoID(arg0, arg1 any) *gomock.Call

ListArtifactsByRepoID indicates an expected call of ListArtifactsByRepoID.

func (*MockStoreMockRecorder) ListFlushCache added in v0.0.17

func (mr *MockStoreMockRecorder) ListFlushCache(arg0 any) *gomock.Call

ListFlushCache indicates an expected call of ListFlushCache.

func (*MockStoreMockRecorder) ListInvitationsForProject added in v0.0.52

func (mr *MockStoreMockRecorder) ListInvitationsForProject(arg0, arg1 any) *gomock.Call

ListInvitationsForProject indicates an expected call of ListInvitationsForProject.

func (*MockStoreMockRecorder) ListNonOrgProjects added in v0.0.35

func (mr *MockStoreMockRecorder) ListNonOrgProjects(arg0 any) *gomock.Call

ListNonOrgProjects indicates an expected call of ListNonOrgProjects.

func (*MockStoreMockRecorder) ListOldOrgProjects added in v0.0.35

func (mr *MockStoreMockRecorder) ListOldOrgProjects(arg0 any) *gomock.Call

ListOldOrgProjects indicates an expected call of ListOldOrgProjects.

func (*MockStoreMockRecorder) ListOldestRuleEvaluationsByRepositoryId added in v0.0.52

func (mr *MockStoreMockRecorder) ListOldestRuleEvaluationsByRepositoryId(arg0, arg1 any) *gomock.Call

ListOldestRuleEvaluationsByRepositoryId indicates an expected call of ListOldestRuleEvaluationsByRepositoryId.

func (*MockStoreMockRecorder) ListProfilesByProjectID

func (mr *MockStoreMockRecorder) ListProfilesByProjectID(arg0, arg1 any) *gomock.Call

ListProfilesByProjectID indicates an expected call of ListProfilesByProjectID.

func (*MockStoreMockRecorder) ListProfilesByProjectIDAndLabel added in v0.0.38

func (mr *MockStoreMockRecorder) ListProfilesByProjectIDAndLabel(arg0, arg1 any) *gomock.Call

ListProfilesByProjectIDAndLabel indicates an expected call of ListProfilesByProjectIDAndLabel.

func (*MockStoreMockRecorder) ListProfilesInstantiatingRuleType

func (mr *MockStoreMockRecorder) ListProfilesInstantiatingRuleType(arg0, arg1 any) *gomock.Call

ListProfilesInstantiatingRuleType indicates an expected call of ListProfilesInstantiatingRuleType.

func (*MockStoreMockRecorder) ListProvidersByProjectID

func (mr *MockStoreMockRecorder) ListProvidersByProjectID(arg0, arg1 any) *gomock.Call

ListProvidersByProjectID indicates an expected call of ListProvidersByProjectID.

func (*MockStoreMockRecorder) ListProvidersByProjectIDPaginated added in v0.0.30

func (mr *MockStoreMockRecorder) ListProvidersByProjectIDPaginated(arg0, arg1 any) *gomock.Call

ListProvidersByProjectIDPaginated indicates an expected call of ListProvidersByProjectIDPaginated.

func (*MockStoreMockRecorder) ListRegisteredRepositoriesByProjectIDAndProvider

func (mr *MockStoreMockRecorder) ListRegisteredRepositoriesByProjectIDAndProvider(arg0, arg1 any) *gomock.Call

ListRegisteredRepositoriesByProjectIDAndProvider indicates an expected call of ListRegisteredRepositoriesByProjectIDAndProvider.

func (*MockStoreMockRecorder) ListRepositoriesAfterID added in v0.0.52

func (mr *MockStoreMockRecorder) ListRepositoriesAfterID(arg0, arg1 any) *gomock.Call

ListRepositoriesAfterID indicates an expected call of ListRepositoriesAfterID.

func (*MockStoreMockRecorder) ListRepositoriesByProjectID

func (mr *MockStoreMockRecorder) ListRepositoriesByProjectID(arg0, arg1 any) *gomock.Call

ListRepositoriesByProjectID indicates an expected call of ListRepositoriesByProjectID.

func (*MockStoreMockRecorder) ListRuleEvaluationsByProfileId

func (mr *MockStoreMockRecorder) ListRuleEvaluationsByProfileId(arg0, arg1 any) *gomock.Call

ListRuleEvaluationsByProfileId indicates an expected call of ListRuleEvaluationsByProfileId.

func (*MockStoreMockRecorder) ListRuleTypesByProject added in v0.0.39

func (mr *MockStoreMockRecorder) ListRuleTypesByProject(arg0, arg1 any) *gomock.Call

ListRuleTypesByProject indicates an expected call of ListRuleTypesByProject.

func (*MockStoreMockRecorder) ListTokensToMigrate added in v0.0.52

func (mr *MockStoreMockRecorder) ListTokensToMigrate(arg0, arg1 any) *gomock.Call

ListTokensToMigrate indicates an expected call of ListTokensToMigrate.

func (*MockStoreMockRecorder) ListUsers

func (mr *MockStoreMockRecorder) ListUsers(arg0, arg1 any) *gomock.Call

ListUsers indicates an expected call of ListUsers.

func (*MockStoreMockRecorder) LockIfThresholdNotExceeded added in v0.0.17

func (mr *MockStoreMockRecorder) LockIfThresholdNotExceeded(arg0, arg1 any) *gomock.Call

LockIfThresholdNotExceeded indicates an expected call of LockIfThresholdNotExceeded.

func (*MockStoreMockRecorder) OrphanProject added in v0.0.35

func (mr *MockStoreMockRecorder) OrphanProject(arg0, arg1 any) *gomock.Call

OrphanProject indicates an expected call of OrphanProject.

func (*MockStoreMockRecorder) ReleaseLock added in v0.0.17

func (mr *MockStoreMockRecorder) ReleaseLock(arg0, arg1 any) *gomock.Call

ReleaseLock indicates an expected call of ReleaseLock.

func (*MockStoreMockRecorder) RepositoryExistsAfterID added in v0.0.52

func (mr *MockStoreMockRecorder) RepositoryExistsAfterID(arg0, arg1 any) *gomock.Call

RepositoryExistsAfterID indicates an expected call of RepositoryExistsAfterID.

func (*MockStoreMockRecorder) Rollback

func (mr *MockStoreMockRecorder) Rollback(arg0 any) *gomock.Call

Rollback indicates an expected call of Rollback.

func (*MockStoreMockRecorder) SetCurrentVersion added in v0.0.37

func (mr *MockStoreMockRecorder) SetCurrentVersion(arg0, arg1 any) *gomock.Call

SetCurrentVersion indicates an expected call of SetCurrentVersion.

func (*MockStoreMockRecorder) UpdateEncryptedSecret added in v0.0.52

func (mr *MockStoreMockRecorder) UpdateEncryptedSecret(arg0, arg1 any) *gomock.Call

UpdateEncryptedSecret indicates an expected call of UpdateEncryptedSecret.

func (*MockStoreMockRecorder) UpdateEvaluationTimes added in v0.0.53

func (mr *MockStoreMockRecorder) UpdateEvaluationTimes(arg0, arg1 any) *gomock.Call

UpdateEvaluationTimes indicates an expected call of UpdateEvaluationTimes.

func (*MockStoreMockRecorder) UpdateInvitation added in v0.0.53

func (mr *MockStoreMockRecorder) UpdateInvitation(arg0, arg1 any) *gomock.Call

UpdateInvitation indicates an expected call of UpdateInvitation.

func (*MockStoreMockRecorder) UpdateLease added in v0.0.17

func (mr *MockStoreMockRecorder) UpdateLease(arg0, arg1 any) *gomock.Call

UpdateLease indicates an expected call of UpdateLease.

func (*MockStoreMockRecorder) UpdateProfile added in v0.0.16

func (mr *MockStoreMockRecorder) UpdateProfile(arg0, arg1 any) *gomock.Call

UpdateProfile indicates an expected call of UpdateProfile.

func (*MockStoreMockRecorder) UpdateProjectMeta added in v0.0.35

func (mr *MockStoreMockRecorder) UpdateProjectMeta(arg0, arg1 any) *gomock.Call

UpdateProjectMeta indicates an expected call of UpdateProjectMeta.

func (*MockStoreMockRecorder) UpdateProvider added in v0.0.35

func (mr *MockStoreMockRecorder) UpdateProvider(arg0, arg1 any) *gomock.Call

UpdateProvider indicates an expected call of UpdateProvider.

func (*MockStoreMockRecorder) UpdateReminderLastSentById added in v0.0.52

func (mr *MockStoreMockRecorder) UpdateReminderLastSentById(arg0, arg1 any) *gomock.Call

UpdateReminderLastSentById indicates an expected call of UpdateReminderLastSentById.

func (*MockStoreMockRecorder) UpdateRuleType

func (mr *MockStoreMockRecorder) UpdateRuleType(arg0, arg1 any) *gomock.Call

UpdateRuleType indicates an expected call of UpdateRuleType.

func (*MockStoreMockRecorder) UpsertAccessToken added in v0.0.33

func (mr *MockStoreMockRecorder) UpsertAccessToken(arg0, arg1 any) *gomock.Call

UpsertAccessToken indicates an expected call of UpsertAccessToken.

func (*MockStoreMockRecorder) UpsertArtifact

func (mr *MockStoreMockRecorder) UpsertArtifact(arg0, arg1 any) *gomock.Call

UpsertArtifact indicates an expected call of UpsertArtifact.

func (*MockStoreMockRecorder) UpsertBundle added in v0.0.37

func (mr *MockStoreMockRecorder) UpsertBundle(arg0, arg1 any) *gomock.Call

UpsertBundle indicates an expected call of UpsertBundle.

func (*MockStoreMockRecorder) UpsertInstallationID added in v0.0.38

func (mr *MockStoreMockRecorder) UpsertInstallationID(arg0, arg1 any) *gomock.Call

UpsertInstallationID indicates an expected call of UpsertInstallationID.

func (*MockStoreMockRecorder) UpsertLatestEvaluationStatus added in v0.0.53

func (mr *MockStoreMockRecorder) UpsertLatestEvaluationStatus(arg0, arg1 any) *gomock.Call

UpsertLatestEvaluationStatus indicates an expected call of UpsertLatestEvaluationStatus.

func (*MockStoreMockRecorder) UpsertProfileForEntity added in v0.0.16

func (mr *MockStoreMockRecorder) UpsertProfileForEntity(arg0, arg1 any) *gomock.Call

UpsertProfileForEntity indicates an expected call of UpsertProfileForEntity.

func (*MockStoreMockRecorder) UpsertPullRequest

func (mr *MockStoreMockRecorder) UpsertPullRequest(arg0, arg1 any) *gomock.Call

UpsertPullRequest indicates an expected call of UpsertPullRequest.

func (*MockStoreMockRecorder) UpsertRuleDetailsAlert

func (mr *MockStoreMockRecorder) UpsertRuleDetailsAlert(arg0, arg1 any) *gomock.Call

UpsertRuleDetailsAlert indicates an expected call of UpsertRuleDetailsAlert.

func (*MockStoreMockRecorder) UpsertRuleDetailsEval

func (mr *MockStoreMockRecorder) UpsertRuleDetailsEval(arg0, arg1 any) *gomock.Call

UpsertRuleDetailsEval indicates an expected call of UpsertRuleDetailsEval.

func (*MockStoreMockRecorder) UpsertRuleDetailsRemediate

func (mr *MockStoreMockRecorder) UpsertRuleDetailsRemediate(arg0, arg1 any) *gomock.Call

UpsertRuleDetailsRemediate indicates an expected call of UpsertRuleDetailsRemediate.

func (*MockStoreMockRecorder) UpsertRuleEvaluations

func (mr *MockStoreMockRecorder) UpsertRuleEvaluations(arg0, arg1 any) *gomock.Call

UpsertRuleEvaluations indicates an expected call of UpsertRuleEvaluations.

func (*MockStoreMockRecorder) UpsertRuleInstance added in v0.0.52

func (mr *MockStoreMockRecorder) UpsertRuleInstance(arg0, arg1 any) *gomock.Call

UpsertRuleInstance indicates an expected call of UpsertRuleInstance.

func (*MockStoreMockRecorder) UpsertRuleInstantiation

func (mr *MockStoreMockRecorder) UpsertRuleInstantiation(arg0, arg1 any) *gomock.Call

UpsertRuleInstantiation indicates an expected call of UpsertRuleInstantiation.

Directories

Path Synopsis
Package fixtures contains code for creating RepositoryService fixtures and is used in various parts of the code.
Package fixtures contains code for creating RepositoryService fixtures and is used in various parts of the code.

Jump to