artifacts

package
v0.0.55 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 15, 2024 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Overview

Package artifacts stores logic relating to the artifact entity type

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetArtifact

func GetArtifact(
	ctx context.Context,
	store db.Querier,
	projectID uuid.UUID,
	artifactID uuid.UUID,
) (uuid.UUID, *minderv1.Artifact, error)

GetArtifact retrieves an artifact and its versions from the database Returns provider ID alongside the artifact

Types

This section is empty.

Jump to