Documentation
¶
Overview ¶
Package client contains the configuration for the minder cli
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
type Config struct {
GRPCClientConfig config.GRPCClientConfig `mapstructure:"grpc_server"`
Identity IdentityConfigWrapper `mapstructure:"identity"`
}
Config is the configuration for the minder cli
type IdentityConfig ¶
type IdentityConfig struct {
// IssuerUrl is the base URL where the identity server is running
IssuerUrl string `mapstructure:"issuer_url" default:"https://auth.stacklok.com"`
// ClientId is the client ID that identifies the server client ID
ClientId string `mapstructure:"client_id" default:"minder-cli"`
}
IdentityConfig is the configuration for the identity provider used by minder-cli
type IdentityConfigWrapper ¶
type IdentityConfigWrapper struct {
CLI IdentityConfig `mapstructure:"cli"`
}
IdentityConfigWrapper is the configuration wrapper for the identity provider used by minder-cli
Click to show internal directories.
Click to hide internal directories.