Documentation
¶
Overview ¶
Package crypto provides cryptographic functions
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EncryptBytes ¶
EncryptBytes encrypts a row of data using AES-CFB.
func GenerateNonce ¶
GenerateNonce generates a nonce for the OAuth2 flow. The nonce is a base64 encoded
Types ¶
type Engine ¶
type Engine struct {
// contains filtered or unexported fields
}
Engine is a structure that allows controller access to cryptographic functions. The intention is that this structure will be passed to the controller on creation and will validate that wrong parameters aren't passed to the functions.
func EngineFromAuthConfig ¶
func EngineFromAuthConfig(authConfig *serverconfig.AuthConfig) (*Engine, error)
EngineFromAuthConfig creates a new crypto engine from an auth config
func (*Engine) DecryptOAuthToken ¶
DecryptOAuthToken decrypts an encrypted oauth token
Click to show internal directories.
Click to hide internal directories.