alert

package
v0.0.34 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 5, 2024 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Overview

Package alert provides necessary interfaces and implementations for processing alerts.

Index

Constants

const ActionType engif.ActionType = "alert"

ActionType is the type of the alert engine

Variables

This section is empty.

Functions

func NewRuleAlert

func NewRuleAlert(rt *pb.RuleType, pbuild *providers.ProviderBuilder) (engif.Action, error)

NewRuleAlert creates a new rule alert engine

Types

This section is empty.

Directories

Path Synopsis
Package noop provides a fallback alert engine for cases where no alert is set.
Package noop provides a fallback alert engine for cases where no alert is set.
Package security_advisory provides necessary interfaces and implementations for creating alerts of type security advisory.
Package security_advisory provides necessary interfaces and implementations for creating alerts of type security advisory.

Jump to