eval

package
v0.0.21 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 14, 2023 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Overview

Package eval provides necessary interfaces and implementations for evaluating rules.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewRuleEvaluator

func NewRuleEvaluator(rt *pb.RuleType, cli *providers.ProviderBuilder) (engif.Evaluator, error)

NewRuleEvaluator creates a new rule data evaluator

Types

This section is empty.

Directories

Path Synopsis
Package jq provides the jq profile evaluator
Package jq provides the jq profile evaluator
Package pr_actions contains shared code to take on PRs
Package pr_actions contains shared code to take on PRs
Package rego provides the rego rule evaluator
Package rego provides the rego rule evaluator
Package trusty provides an evaluator that uses the trusty API
Package trusty provides an evaluator that uses the trusty API
Package vulncheck provides the vulnerability check evaluator
Package vulncheck provides the vulnerability check evaluator

Jump to