mock_events

package
v0.0.49 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 16, 2024 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Overview

Package mock_events is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockAggregatorMiddleware added in v0.0.48

type MockAggregatorMiddleware struct {
	// contains filtered or unexported fields
}

MockAggregatorMiddleware is a mock of AggregatorMiddleware interface.

func NewMockAggregatorMiddleware added in v0.0.48

func NewMockAggregatorMiddleware(ctrl *gomock.Controller) *MockAggregatorMiddleware

NewMockAggregatorMiddleware creates a new mock instance.

func (*MockAggregatorMiddleware) AggregateMiddleware added in v0.0.48

AggregateMiddleware mocks base method.

func (*MockAggregatorMiddleware) EXPECT added in v0.0.48

EXPECT returns an object that allows the caller to indicate expected use.

type MockAggregatorMiddlewareMockRecorder added in v0.0.48

type MockAggregatorMiddlewareMockRecorder struct {
	// contains filtered or unexported fields
}

MockAggregatorMiddlewareMockRecorder is the mock recorder for MockAggregatorMiddleware.

func (*MockAggregatorMiddlewareMockRecorder) AggregateMiddleware added in v0.0.48

func (mr *MockAggregatorMiddlewareMockRecorder) AggregateMiddleware(h any) *gomock.Call

AggregateMiddleware indicates an expected call of AggregateMiddleware.

type MockConsumer added in v0.0.48

type MockConsumer struct {
	// contains filtered or unexported fields
}

MockConsumer is a mock of Consumer interface.

func NewMockConsumer added in v0.0.48

func NewMockConsumer(ctrl *gomock.Controller) *MockConsumer

NewMockConsumer creates a new mock instance.

func (*MockConsumer) EXPECT added in v0.0.48

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockConsumer) Register added in v0.0.48

func (m *MockConsumer) Register(arg0 events.Registrar)

Register mocks base method.

type MockConsumerMockRecorder added in v0.0.48

type MockConsumerMockRecorder struct {
	// contains filtered or unexported fields
}

MockConsumerMockRecorder is the mock recorder for MockConsumer.

func (*MockConsumerMockRecorder) Register added in v0.0.48

func (mr *MockConsumerMockRecorder) Register(arg0 any) *gomock.Call

Register indicates an expected call of Register.

type MockInterface

type MockInterface struct {
	// contains filtered or unexported fields
}

MockInterface is a mock of Interface interface.

func NewMockInterface

func NewMockInterface(ctrl *gomock.Controller) *MockInterface

NewMockInterface creates a new mock instance.

func (*MockInterface) Close

func (m *MockInterface) Close() error

Close mocks base method.

func (*MockInterface) ConsumeEvents

func (m *MockInterface) ConsumeEvents(consumers ...events.Consumer)

ConsumeEvents mocks base method.

func (*MockInterface) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockInterface) Publish

func (m *MockInterface) Publish(topic string, messages ...*message.Message) error

Publish mocks base method.

func (*MockInterface) Register

func (m *MockInterface) Register(topic string, handler events.Handler, mdw ...message.HandlerMiddleware)

Register mocks base method.

func (*MockInterface) Run

func (m *MockInterface) Run(ctx context.Context) error

Run mocks base method.

func (*MockInterface) Running

func (m *MockInterface) Running() chan struct{}

Running mocks base method.

type MockInterfaceMockRecorder

type MockInterfaceMockRecorder struct {
	// contains filtered or unexported fields
}

MockInterfaceMockRecorder is the mock recorder for MockInterface.

func (*MockInterfaceMockRecorder) Close

func (mr *MockInterfaceMockRecorder) Close() *gomock.Call

Close indicates an expected call of Close.

func (*MockInterfaceMockRecorder) ConsumeEvents

func (mr *MockInterfaceMockRecorder) ConsumeEvents(consumers ...any) *gomock.Call

ConsumeEvents indicates an expected call of ConsumeEvents.

func (*MockInterfaceMockRecorder) Publish

func (mr *MockInterfaceMockRecorder) Publish(topic any, messages ...any) *gomock.Call

Publish indicates an expected call of Publish.

func (*MockInterfaceMockRecorder) Register

func (mr *MockInterfaceMockRecorder) Register(topic, handler any, mdw ...any) *gomock.Call

Register indicates an expected call of Register.

func (*MockInterfaceMockRecorder) Run

func (mr *MockInterfaceMockRecorder) Run(ctx any) *gomock.Call

Run indicates an expected call of Run.

func (*MockInterfaceMockRecorder) Running

func (mr *MockInterfaceMockRecorder) Running() *gomock.Call

Running indicates an expected call of Running.

type MockPublisher added in v0.0.48

type MockPublisher struct {
	// contains filtered or unexported fields
}

MockPublisher is a mock of Publisher interface.

func NewMockPublisher added in v0.0.48

func NewMockPublisher(ctrl *gomock.Controller) *MockPublisher

NewMockPublisher creates a new mock instance.

func (*MockPublisher) EXPECT added in v0.0.48

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockPublisher) Publish added in v0.0.48

func (m *MockPublisher) Publish(topic string, messages ...*message.Message) error

Publish mocks base method.

type MockPublisherMockRecorder added in v0.0.48

type MockPublisherMockRecorder struct {
	// contains filtered or unexported fields
}

MockPublisherMockRecorder is the mock recorder for MockPublisher.

func (*MockPublisherMockRecorder) Publish added in v0.0.48

func (mr *MockPublisherMockRecorder) Publish(topic any, messages ...any) *gomock.Call

Publish indicates an expected call of Publish.

type MockRegistrar added in v0.0.48

type MockRegistrar struct {
	// contains filtered or unexported fields
}

MockRegistrar is a mock of Registrar interface.

func NewMockRegistrar added in v0.0.48

func NewMockRegistrar(ctrl *gomock.Controller) *MockRegistrar

NewMockRegistrar creates a new mock instance.

func (*MockRegistrar) EXPECT added in v0.0.48

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockRegistrar) Register added in v0.0.48

func (m *MockRegistrar) Register(topic string, handler events.Handler, mdw ...message.HandlerMiddleware)

Register mocks base method.

type MockRegistrarMockRecorder added in v0.0.48

type MockRegistrarMockRecorder struct {
	// contains filtered or unexported fields
}

MockRegistrarMockRecorder is the mock recorder for MockRegistrar.

func (*MockRegistrarMockRecorder) Register added in v0.0.48

func (mr *MockRegistrarMockRecorder) Register(topic, handler any, mdw ...any) *gomock.Call

Register indicates an expected call of Register.

type MockService added in v0.0.48

type MockService struct {
	// contains filtered or unexported fields
}

MockService is a mock of Service interface.

func NewMockService added in v0.0.48

func NewMockService(ctrl *gomock.Controller) *MockService

NewMockService creates a new mock instance.

func (*MockService) Close added in v0.0.48

func (m *MockService) Close() error

Close mocks base method.

func (*MockService) ConsumeEvents added in v0.0.48

func (m *MockService) ConsumeEvents(consumers ...events.Consumer)

ConsumeEvents mocks base method.

func (*MockService) EXPECT added in v0.0.48

func (m *MockService) EXPECT() *MockServiceMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockService) Run added in v0.0.48

func (m *MockService) Run(ctx context.Context) error

Run mocks base method.

func (*MockService) Running added in v0.0.48

func (m *MockService) Running() chan struct{}

Running mocks base method.

type MockServiceMockRecorder added in v0.0.48

type MockServiceMockRecorder struct {
	// contains filtered or unexported fields
}

MockServiceMockRecorder is the mock recorder for MockService.

func (*MockServiceMockRecorder) Close added in v0.0.48

func (mr *MockServiceMockRecorder) Close() *gomock.Call

Close indicates an expected call of Close.

func (*MockServiceMockRecorder) ConsumeEvents added in v0.0.48

func (mr *MockServiceMockRecorder) ConsumeEvents(consumers ...any) *gomock.Call

ConsumeEvents indicates an expected call of ConsumeEvents.

func (*MockServiceMockRecorder) Run added in v0.0.48

func (mr *MockServiceMockRecorder) Run(ctx any) *gomock.Call

Run indicates an expected call of Run.

func (*MockServiceMockRecorder) Running added in v0.0.48

func (mr *MockServiceMockRecorder) Running() *gomock.Call

Running indicates an expected call of Running.

Jump to