mockgh

package
v0.0.45 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 12, 2024 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Overview

Package mockgh is a generated GoMock package.

Package mockgh is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockClientService added in v0.0.39

type MockClientService struct {
	// contains filtered or unexported fields
}

MockClientService is a mock of ClientService interface.

func NewMockClientService added in v0.0.39

func NewMockClientService(ctrl *gomock.Controller) *MockClientService

NewMockClientService creates a new mock instance.

func (*MockClientService) DeleteInstallation added in v0.0.40

func (m *MockClientService) DeleteInstallation(arg0 context.Context, arg1 int64, arg2 string) (*github.Response, error)

DeleteInstallation mocks base method.

func (*MockClientService) EXPECT added in v0.0.39

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockClientService) GetInstallation added in v0.0.39

func (m *MockClientService) GetInstallation(arg0 context.Context, arg1 int64, arg2 string) (*github.Installation, *github.Response, error)

GetInstallation mocks base method.

func (*MockClientService) GetUserIdFromToken added in v0.0.39

func (m *MockClientService) GetUserIdFromToken(arg0 context.Context, arg1 *oauth2.Token) (*int64, error)

GetUserIdFromToken mocks base method.

func (*MockClientService) ListUserInstallations added in v0.0.39

func (m *MockClientService) ListUserInstallations(arg0 context.Context, arg1 *oauth2.Token) ([]*github.Installation, error)

ListUserInstallations mocks base method.

type MockClientServiceMockRecorder added in v0.0.39

type MockClientServiceMockRecorder struct {
	// contains filtered or unexported fields
}

MockClientServiceMockRecorder is the mock recorder for MockClientService.

func (*MockClientServiceMockRecorder) DeleteInstallation added in v0.0.40

func (mr *MockClientServiceMockRecorder) DeleteInstallation(arg0, arg1, arg2 any) *gomock.Call

DeleteInstallation indicates an expected call of DeleteInstallation.

func (*MockClientServiceMockRecorder) GetInstallation added in v0.0.39

func (mr *MockClientServiceMockRecorder) GetInstallation(arg0, arg1, arg2 any) *gomock.Call

GetInstallation indicates an expected call of GetInstallation.

func (*MockClientServiceMockRecorder) GetUserIdFromToken added in v0.0.39

func (mr *MockClientServiceMockRecorder) GetUserIdFromToken(arg0, arg1 any) *gomock.Call

GetUserIdFromToken indicates an expected call of GetUserIdFromToken.

func (*MockClientServiceMockRecorder) ListUserInstallations added in v0.0.39

func (mr *MockClientServiceMockRecorder) ListUserInstallations(arg0, arg1 any) *gomock.Call

ListUserInstallations indicates an expected call of ListUserInstallations.

type MockGit

type MockGit struct {
	// contains filtered or unexported fields
}

MockGit is a mock of Git interface.

func NewMockGit

func NewMockGit(ctrl *gomock.Controller) *MockGit

NewMockGit creates a new mock instance.

func (*MockGit) Clone

func (m *MockGit) Clone(ctx context.Context, url, branch string) (*git.Repository, error)

Clone mocks base method.

func (*MockGit) EXPECT

func (m *MockGit) EXPECT() *MockGitMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

type MockGitHub

type MockGitHub struct {
	// contains filtered or unexported fields
}

MockGitHub is a mock of GitHub interface.

func NewMockGitHub

func NewMockGitHub(ctrl *gomock.Controller) *MockGitHub

NewMockGitHub creates a new mock instance.

func (*MockGitHub) AddAuthToPushOptions added in v0.0.36

func (m *MockGitHub) AddAuthToPushOptions(ctx context.Context, options *git.PushOptions) error

AddAuthToPushOptions mocks base method.

func (*MockGitHub) Clone added in v0.0.35

func (m *MockGitHub) Clone(ctx context.Context, url, branch string) (*git.Repository, error)

Clone mocks base method.

func (*MockGitHub) ClosePullRequest added in v0.0.39

func (m *MockGitHub) ClosePullRequest(ctx context.Context, owner, repo string, number int) (*github.PullRequest, error)

ClosePullRequest mocks base method.

func (*MockGitHub) CloseSecurityAdvisory

func (m *MockGitHub) CloseSecurityAdvisory(ctx context.Context, owner, repo, id string) error

CloseSecurityAdvisory mocks base method.

func (*MockGitHub) CreateHook

func (m *MockGitHub) CreateHook(ctx context.Context, owner, repo string, hook *github.Hook) (*github.Hook, error)

CreateHook mocks base method.

func (*MockGitHub) CreateIssueComment added in v0.0.35

func (m *MockGitHub) CreateIssueComment(ctx context.Context, owner, repo string, number int, comment string) (*github.IssueComment, error)

CreateIssueComment mocks base method.

func (*MockGitHub) CreatePullRequest

func (m *MockGitHub) CreatePullRequest(ctx context.Context, owner, repo, title, body, head, base string) (*github.PullRequest, error)

CreatePullRequest mocks base method.

func (*MockGitHub) CreateReview

func (m *MockGitHub) CreateReview(arg0 context.Context, arg1, arg2 string, arg3 int, arg4 *github.PullRequestReviewRequest) (*github.PullRequestReview, error)

CreateReview mocks base method.

func (*MockGitHub) CreateSecurityAdvisory

func (m *MockGitHub) CreateSecurityAdvisory(ctx context.Context, owner, repo, severity, summary, description string, v []*github.AdvisoryVulnerability) (string, error)

CreateSecurityAdvisory mocks base method.

func (*MockGitHub) DeleteHook

func (m *MockGitHub) DeleteHook(ctx context.Context, owner, repo string, id int64) (*github.Response, error)

DeleteHook mocks base method.

func (*MockGitHub) DismissReview

func (m *MockGitHub) DismissReview(arg0 context.Context, arg1, arg2 string, arg3 int, arg4 int64, arg5 *github.PullRequestReviewDismissalRequest) (*github.PullRequestReview, error)

DismissReview mocks base method.

func (*MockGitHub) Do

func (m *MockGitHub) Do(ctx context.Context, req *http.Request) (*http.Response, error)

Do mocks base method.

func (*MockGitHub) EXPECT

func (m *MockGitHub) EXPECT() *MockGitHubMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockGitHub) EditHook added in v0.0.37

func (m *MockGitHub) EditHook(ctx context.Context, owner, repo string, id int64, hook *github.Hook) (*github.Hook, error)

EditHook mocks base method.

func (*MockGitHub) GetBaseURL

func (m *MockGitHub) GetBaseURL() string

GetBaseURL mocks base method.

func (*MockGitHub) GetBranchProtection

func (m *MockGitHub) GetBranchProtection(arg0 context.Context, arg1, arg2, arg3 string) (*github.Protection, error)

GetBranchProtection mocks base method.

func (*MockGitHub) GetCredential added in v0.0.36

func (m *MockGitHub) GetCredential() v10.GitHubCredential

GetCredential mocks base method.

func (*MockGitHub) GetLogin added in v0.0.36

func (m *MockGitHub) GetLogin(ctx context.Context) (string, error)

GetLogin mocks base method.

func (*MockGitHub) GetName added in v0.0.36

func (m *MockGitHub) GetName(ctx context.Context) (string, error)

GetName mocks base method.

func (*MockGitHub) GetPackageByName

func (m *MockGitHub) GetPackageByName(arg0 context.Context, arg1, arg2, arg3 string) (*github.Package, error)

GetPackageByName mocks base method.

func (*MockGitHub) GetPackageVersionById

func (m *MockGitHub) GetPackageVersionById(arg0 context.Context, arg1, arg2, arg3 string, arg4 int64) (*github.PackageVersion, error)

GetPackageVersionById mocks base method.

func (*MockGitHub) GetPackageVersionByTag

func (m *MockGitHub) GetPackageVersionByTag(arg0 context.Context, arg1, arg2, arg3, arg4 string) (*github.PackageVersion, error)

GetPackageVersionByTag mocks base method.

func (*MockGitHub) GetPackageVersions

func (m *MockGitHub) GetPackageVersions(arg0 context.Context, arg1, arg2, arg3 string) ([]*github.PackageVersion, error)

GetPackageVersions mocks base method.

func (*MockGitHub) GetPrimaryEmail added in v0.0.35

func (m *MockGitHub) GetPrimaryEmail(ctx context.Context) (string, error)

GetPrimaryEmail mocks base method.

func (*MockGitHub) GetPullRequest

func (m *MockGitHub) GetPullRequest(arg0 context.Context, arg1, arg2 string, arg3 int) (*github.PullRequest, error)

GetPullRequest mocks base method.

func (*MockGitHub) GetRepository

func (m *MockGitHub) GetRepository(arg0 context.Context, arg1, arg2 string) (*github.Repository, error)

GetRepository mocks base method.

func (*MockGitHub) GetUserId added in v0.0.35

func (m *MockGitHub) GetUserId(ctx context.Context) (int64, error)

GetUserId mocks base method.

func (*MockGitHub) IsOrg added in v0.0.41

func (m *MockGitHub) IsOrg() bool

IsOrg mocks base method.

func (*MockGitHub) ListAllRepositories

func (m *MockGitHub) ListAllRepositories(arg0 context.Context) ([]*v1.Repository, error)

ListAllRepositories mocks base method.

func (*MockGitHub) ListFiles

func (m *MockGitHub) ListFiles(ctx context.Context, owner, repo string, prNumber, perPage, pageNumber int) ([]*github.CommitFile, *github.Response, error)

ListFiles mocks base method.

func (*MockGitHub) ListHooks

func (m *MockGitHub) ListHooks(ctx context.Context, owner, repo string) ([]*github.Hook, error)

ListHooks mocks base method.

func (*MockGitHub) ListIssueComments added in v0.0.35

func (m *MockGitHub) ListIssueComments(ctx context.Context, owner, repo string, number int, opts *github.IssueListCommentsOptions) ([]*github.IssueComment, error)

ListIssueComments mocks base method.

func (*MockGitHub) ListPackagesByRepository

func (m *MockGitHub) ListPackagesByRepository(arg0 context.Context, arg1, arg2 string, arg3 int64, arg4, arg5 int) ([]*github.Package, error)

ListPackagesByRepository mocks base method.

func (*MockGitHub) ListPullRequests

func (m *MockGitHub) ListPullRequests(ctx context.Context, owner, repo string, opt *github.PullRequestListOptions) ([]*github.PullRequest, error)

ListPullRequests mocks base method.

func (*MockGitHub) ListReviews

func (m *MockGitHub) ListReviews(arg0 context.Context, arg1, arg2 string, arg3 int, arg4 *github.ListOptions) ([]*github.PullRequestReview, error)

ListReviews mocks base method.

func (*MockGitHub) NewRequest

func (m *MockGitHub) NewRequest(method, url string, body any) (*http.Request, error)

NewRequest mocks base method.

func (*MockGitHub) SetCommitStatus

func (m *MockGitHub) SetCommitStatus(arg0 context.Context, arg1, arg2, arg3 string, arg4 *github.RepoStatus) (*github.RepoStatus, error)

SetCommitStatus mocks base method.

func (*MockGitHub) UpdateBranchProtection

func (m *MockGitHub) UpdateBranchProtection(arg0 context.Context, arg1, arg2, arg3 string, arg4 *github.ProtectionRequest) error

UpdateBranchProtection mocks base method.

func (*MockGitHub) UpdateIssueComment added in v0.0.35

func (m *MockGitHub) UpdateIssueComment(ctx context.Context, owner, repo string, number int64, comment string) error

UpdateIssueComment mocks base method.

func (*MockGitHub) UpdateReview added in v0.0.35

func (m *MockGitHub) UpdateReview(arg0 context.Context, arg1, arg2 string, arg3 int, arg4 int64, arg5 string) (*github.PullRequestReview, error)

UpdateReview mocks base method.

type MockGitHubMockRecorder

type MockGitHubMockRecorder struct {
	// contains filtered or unexported fields
}

MockGitHubMockRecorder is the mock recorder for MockGitHub.

func (*MockGitHubMockRecorder) AddAuthToPushOptions added in v0.0.36

func (mr *MockGitHubMockRecorder) AddAuthToPushOptions(ctx, options any) *gomock.Call

AddAuthToPushOptions indicates an expected call of AddAuthToPushOptions.

func (*MockGitHubMockRecorder) Clone added in v0.0.35

func (mr *MockGitHubMockRecorder) Clone(ctx, url, branch any) *gomock.Call

Clone indicates an expected call of Clone.

func (*MockGitHubMockRecorder) ClosePullRequest added in v0.0.39

func (mr *MockGitHubMockRecorder) ClosePullRequest(ctx, owner, repo, number any) *gomock.Call

ClosePullRequest indicates an expected call of ClosePullRequest.

func (*MockGitHubMockRecorder) CloseSecurityAdvisory

func (mr *MockGitHubMockRecorder) CloseSecurityAdvisory(ctx, owner, repo, id any) *gomock.Call

CloseSecurityAdvisory indicates an expected call of CloseSecurityAdvisory.

func (*MockGitHubMockRecorder) CreateHook

func (mr *MockGitHubMockRecorder) CreateHook(ctx, owner, repo, hook any) *gomock.Call

CreateHook indicates an expected call of CreateHook.

func (*MockGitHubMockRecorder) CreateIssueComment added in v0.0.35

func (mr *MockGitHubMockRecorder) CreateIssueComment(ctx, owner, repo, number, comment any) *gomock.Call

CreateIssueComment indicates an expected call of CreateIssueComment.

func (*MockGitHubMockRecorder) CreatePullRequest

func (mr *MockGitHubMockRecorder) CreatePullRequest(ctx, owner, repo, title, body, head, base any) *gomock.Call

CreatePullRequest indicates an expected call of CreatePullRequest.

func (*MockGitHubMockRecorder) CreateReview

func (mr *MockGitHubMockRecorder) CreateReview(arg0, arg1, arg2, arg3, arg4 any) *gomock.Call

CreateReview indicates an expected call of CreateReview.

func (*MockGitHubMockRecorder) CreateSecurityAdvisory

func (mr *MockGitHubMockRecorder) CreateSecurityAdvisory(ctx, owner, repo, severity, summary, description, v any) *gomock.Call

CreateSecurityAdvisory indicates an expected call of CreateSecurityAdvisory.

func (*MockGitHubMockRecorder) DeleteHook

func (mr *MockGitHubMockRecorder) DeleteHook(ctx, owner, repo, id any) *gomock.Call

DeleteHook indicates an expected call of DeleteHook.

func (*MockGitHubMockRecorder) DismissReview

func (mr *MockGitHubMockRecorder) DismissReview(arg0, arg1, arg2, arg3, arg4, arg5 any) *gomock.Call

DismissReview indicates an expected call of DismissReview.

func (*MockGitHubMockRecorder) Do

func (mr *MockGitHubMockRecorder) Do(ctx, req any) *gomock.Call

Do indicates an expected call of Do.

func (*MockGitHubMockRecorder) EditHook added in v0.0.37

func (mr *MockGitHubMockRecorder) EditHook(ctx, owner, repo, id, hook any) *gomock.Call

EditHook indicates an expected call of EditHook.

func (*MockGitHubMockRecorder) GetBaseURL

func (mr *MockGitHubMockRecorder) GetBaseURL() *gomock.Call

GetBaseURL indicates an expected call of GetBaseURL.

func (*MockGitHubMockRecorder) GetBranchProtection

func (mr *MockGitHubMockRecorder) GetBranchProtection(arg0, arg1, arg2, arg3 any) *gomock.Call

GetBranchProtection indicates an expected call of GetBranchProtection.

func (*MockGitHubMockRecorder) GetCredential added in v0.0.36

func (mr *MockGitHubMockRecorder) GetCredential() *gomock.Call

GetCredential indicates an expected call of GetCredential.

func (*MockGitHubMockRecorder) GetLogin added in v0.0.36

func (mr *MockGitHubMockRecorder) GetLogin(ctx any) *gomock.Call

GetLogin indicates an expected call of GetLogin.

func (*MockGitHubMockRecorder) GetName added in v0.0.36

func (mr *MockGitHubMockRecorder) GetName(ctx any) *gomock.Call

GetName indicates an expected call of GetName.

func (*MockGitHubMockRecorder) GetPackageByName

func (mr *MockGitHubMockRecorder) GetPackageByName(arg0, arg1, arg2, arg3 any) *gomock.Call

GetPackageByName indicates an expected call of GetPackageByName.

func (*MockGitHubMockRecorder) GetPackageVersionById

func (mr *MockGitHubMockRecorder) GetPackageVersionById(arg0, arg1, arg2, arg3, arg4 any) *gomock.Call

GetPackageVersionById indicates an expected call of GetPackageVersionById.

func (*MockGitHubMockRecorder) GetPackageVersionByTag

func (mr *MockGitHubMockRecorder) GetPackageVersionByTag(arg0, arg1, arg2, arg3, arg4 any) *gomock.Call

GetPackageVersionByTag indicates an expected call of GetPackageVersionByTag.

func (*MockGitHubMockRecorder) GetPackageVersions

func (mr *MockGitHubMockRecorder) GetPackageVersions(arg0, arg1, arg2, arg3 any) *gomock.Call

GetPackageVersions indicates an expected call of GetPackageVersions.

func (*MockGitHubMockRecorder) GetPrimaryEmail added in v0.0.35

func (mr *MockGitHubMockRecorder) GetPrimaryEmail(ctx any) *gomock.Call

GetPrimaryEmail indicates an expected call of GetPrimaryEmail.

func (*MockGitHubMockRecorder) GetPullRequest

func (mr *MockGitHubMockRecorder) GetPullRequest(arg0, arg1, arg2, arg3 any) *gomock.Call

GetPullRequest indicates an expected call of GetPullRequest.

func (*MockGitHubMockRecorder) GetRepository

func (mr *MockGitHubMockRecorder) GetRepository(arg0, arg1, arg2 any) *gomock.Call

GetRepository indicates an expected call of GetRepository.

func (*MockGitHubMockRecorder) GetUserId added in v0.0.35

func (mr *MockGitHubMockRecorder) GetUserId(ctx any) *gomock.Call

GetUserId indicates an expected call of GetUserId.

func (*MockGitHubMockRecorder) IsOrg added in v0.0.41

func (mr *MockGitHubMockRecorder) IsOrg() *gomock.Call

IsOrg indicates an expected call of IsOrg.

func (*MockGitHubMockRecorder) ListAllRepositories

func (mr *MockGitHubMockRecorder) ListAllRepositories(arg0 any) *gomock.Call

ListAllRepositories indicates an expected call of ListAllRepositories.

func (*MockGitHubMockRecorder) ListFiles

func (mr *MockGitHubMockRecorder) ListFiles(ctx, owner, repo, prNumber, perPage, pageNumber any) *gomock.Call

ListFiles indicates an expected call of ListFiles.

func (*MockGitHubMockRecorder) ListHooks

func (mr *MockGitHubMockRecorder) ListHooks(ctx, owner, repo any) *gomock.Call

ListHooks indicates an expected call of ListHooks.

func (*MockGitHubMockRecorder) ListIssueComments added in v0.0.35

func (mr *MockGitHubMockRecorder) ListIssueComments(ctx, owner, repo, number, opts any) *gomock.Call

ListIssueComments indicates an expected call of ListIssueComments.

func (*MockGitHubMockRecorder) ListPackagesByRepository

func (mr *MockGitHubMockRecorder) ListPackagesByRepository(arg0, arg1, arg2, arg3, arg4, arg5 any) *gomock.Call

ListPackagesByRepository indicates an expected call of ListPackagesByRepository.

func (*MockGitHubMockRecorder) ListPullRequests

func (mr *MockGitHubMockRecorder) ListPullRequests(ctx, owner, repo, opt any) *gomock.Call

ListPullRequests indicates an expected call of ListPullRequests.

func (*MockGitHubMockRecorder) ListReviews

func (mr *MockGitHubMockRecorder) ListReviews(arg0, arg1, arg2, arg3, arg4 any) *gomock.Call

ListReviews indicates an expected call of ListReviews.

func (*MockGitHubMockRecorder) NewRequest

func (mr *MockGitHubMockRecorder) NewRequest(method, url, body any) *gomock.Call

NewRequest indicates an expected call of NewRequest.

func (*MockGitHubMockRecorder) SetCommitStatus

func (mr *MockGitHubMockRecorder) SetCommitStatus(arg0, arg1, arg2, arg3, arg4 any) *gomock.Call

SetCommitStatus indicates an expected call of SetCommitStatus.

func (*MockGitHubMockRecorder) UpdateBranchProtection

func (mr *MockGitHubMockRecorder) UpdateBranchProtection(arg0, arg1, arg2, arg3, arg4 any) *gomock.Call

UpdateBranchProtection indicates an expected call of UpdateBranchProtection.

func (*MockGitHubMockRecorder) UpdateIssueComment added in v0.0.35

func (mr *MockGitHubMockRecorder) UpdateIssueComment(ctx, owner, repo, number, comment any) *gomock.Call

UpdateIssueComment indicates an expected call of UpdateIssueComment.

func (*MockGitHubMockRecorder) UpdateReview added in v0.0.35

func (mr *MockGitHubMockRecorder) UpdateReview(arg0, arg1, arg2, arg3, arg4, arg5 any) *gomock.Call

UpdateReview indicates an expected call of UpdateReview.

type MockGitMockRecorder

type MockGitMockRecorder struct {
	// contains filtered or unexported fields
}

MockGitMockRecorder is the mock recorder for MockGit.

func (*MockGitMockRecorder) Clone

func (mr *MockGitMockRecorder) Clone(ctx, url, branch any) *gomock.Call

Clone indicates an expected call of Clone.

type MockProvider

type MockProvider struct {
	// contains filtered or unexported fields
}

MockProvider is a mock of Provider interface.

func NewMockProvider

func NewMockProvider(ctrl *gomock.Controller) *MockProvider

NewMockProvider creates a new mock instance.

func (*MockProvider) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

type MockProviderMockRecorder

type MockProviderMockRecorder struct {
	// contains filtered or unexported fields
}

MockProviderMockRecorder is the mock recorder for MockProvider.

type MockREST

type MockREST struct {
	// contains filtered or unexported fields
}

MockREST is a mock of REST interface.

func NewMockREST

func NewMockREST(ctrl *gomock.Controller) *MockREST

NewMockREST creates a new mock instance.

func (*MockREST) Do

func (m *MockREST) Do(ctx context.Context, req *http.Request) (*http.Response, error)

Do mocks base method.

func (*MockREST) EXPECT

func (m *MockREST) EXPECT() *MockRESTMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockREST) GetBaseURL

func (m *MockREST) GetBaseURL() string

GetBaseURL mocks base method.

func (*MockREST) NewRequest

func (m *MockREST) NewRequest(method, url string, body any) (*http.Request, error)

NewRequest mocks base method.

type MockRESTMockRecorder

type MockRESTMockRecorder struct {
	// contains filtered or unexported fields
}

MockRESTMockRecorder is the mock recorder for MockREST.

func (*MockRESTMockRecorder) Do

func (mr *MockRESTMockRecorder) Do(ctx, req any) *gomock.Call

Do indicates an expected call of Do.

func (*MockRESTMockRecorder) GetBaseURL

func (mr *MockRESTMockRecorder) GetBaseURL() *gomock.Call

GetBaseURL indicates an expected call of GetBaseURL.

func (*MockRESTMockRecorder) NewRequest

func (mr *MockRESTMockRecorder) NewRequest(method, url, body any) *gomock.Call

NewRequest indicates an expected call of NewRequest.

type MockRepoLister

type MockRepoLister struct {
	// contains filtered or unexported fields
}

MockRepoLister is a mock of RepoLister interface.

func NewMockRepoLister

func NewMockRepoLister(ctrl *gomock.Controller) *MockRepoLister

NewMockRepoLister creates a new mock instance.

func (*MockRepoLister) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockRepoLister) ListAllRepositories added in v0.0.38

func (m *MockRepoLister) ListAllRepositories(arg0 context.Context) ([]*v1.Repository, error)

ListAllRepositories mocks base method.

type MockRepoListerMockRecorder

type MockRepoListerMockRecorder struct {
	// contains filtered or unexported fields
}

MockRepoListerMockRecorder is the mock recorder for MockRepoLister.

func (*MockRepoListerMockRecorder) ListAllRepositories added in v0.0.38

func (mr *MockRepoListerMockRecorder) ListAllRepositories(arg0 any) *gomock.Call

ListAllRepositories indicates an expected call of ListAllRepositories.

Jump to