Documentation
¶
Overview ¶
Package gitlab provides the GitLab OAuth provider implementation
Index ¶
Constants ¶
const ( // RepoPropertyProjectName represents the gitlab project RepoPropertyProjectName = "gitlab/project_name" // RepoPropertyDefaultBranch represents the gitlab default branch RepoPropertyDefaultBranch = "gitlab/default_branch" // RepoPropertyNamespace represents the gitlab repo namespace RepoPropertyNamespace = "gitlab/namespace" // RepoPropertyLicense represents the gitlab repo license RepoPropertyLicense = "gitlab/license" // RepoPropertyCloneURL represents the gitlab repo clone URL RepoPropertyCloneURL = "gitlab/clone_url" // RepoPropertyHookID represents the gitlab repo hook ID RepoPropertyHookID = "gitlab/hook_id" // RepoPropertyHookURL represents the gitlab repo hook URL RepoPropertyHookURL = "gitlab/hook_url" )
const Class = "gitlab"
Class is the string that represents the GitLab provider class
Variables ¶
var AuthorizationFlows = []db.AuthorizationFlow{ db.AuthorizationFlowUserInput, db.AuthorizationFlowOauth2AuthorizationCodeFlow, }
AuthorizationFlows is the list of authorization flows that the DockerHub provider supports
var Implements = []db.ProviderType{ db.ProviderTypeGit, db.ProviderTypeRest, db.ProviderTypeRepoLister, }
Implements is the list of provider types that the DockerHub provider implements
Functions ¶
func MarshalV1Config ¶
func MarshalV1Config(rawCfg json.RawMessage) (json.RawMessage, error)
MarshalV1Config marshals and validates the given config so it can safely be stored in the database
func New ¶
func New( cred provifv1.GitLabCredential, cfg *minderv1.GitLabProviderConfig, webhookURL string, currentWebhookSecret string, ) (*gitlabClient, error)
New creates a new GitLab provider Note that the webhook URL should already contain the provider class in the path
func ParseV1Config ¶
func ParseV1Config(rawCfg json.RawMessage) (*minderv1.GitLabProviderConfig, error)
ParseV1Config parses the raw configuration into a GitLabProviderConfig
TODO: This should be moved to a common location
Types ¶
This section is empty.
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
Package manager contains the GitLabProviderClassManager
|
Package manager contains the GitLabProviderClassManager |
|
Package webhooksecret provides a way to generate and verify secrets for GitLab webhooks.
|
Package webhooksecret provides a way to generate and verify secrets for GitLab webhooks. |
Click to show internal directories.
Click to hide internal directories.