Documentation
¶
Overview ¶
Package reconcilers contains the reconcilers for the various types of entities in minder.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ProfileInitEvent ¶
type ProfileInitEvent struct {
// Project is the project that the event is relevant to
Project uuid.UUID `json:"project"`
}
ProfileInitEvent is an event that is sent to the reconciler topic when a new profile is created. It is used to initialize the profile by iterating over all registered entities for the relevant project and sending a profile evaluation event for each one.
type Reconciler ¶
type Reconciler struct {
// contains filtered or unexported fields
}
Reconciler is a helper that reconciles entities
func NewReconciler ¶
func NewReconciler( store db.Store, evt events.Publisher, cryptoEngine crypto.Engine, providerManager manager.ProviderManager, repositoryService github.RepositoryService, ) (*Reconciler, error)
NewReconciler creates a new reconciler object
func (*Reconciler) Register ¶
func (r *Reconciler) Register(reg events.Registrar)
Register implements the Consumer interface.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.