messages

package
v0.0.61 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 28, 2024 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package messages contains the messages used by the reminder service

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewRepoReminderMessage

func NewRepoReminderMessage(providerId uuid.UUID, repoID int64, projectID uuid.UUID) (*message.Message, error)

NewRepoReminderMessage creates a new repo reminder message

Types

type RepoReminderEvent

type RepoReminderEvent struct {
	// Project is the project that the event is relevant to
	Project uuid.UUID `json:"project"`
	// ProviderID is the provider of the repository
	ProviderID uuid.UUID `json:"provider"`
	// RepositoryID is id of the repository to be reconciled
	RepositoryID int64 `json:"repository"`
}

RepoReminderEvent is an event that is published by the reminder service to trigger repo reconciliation

func RepoReminderEventFromMessage

func RepoReminderEventFromMessage(msg *message.Message) (*RepoReminderEvent, error)

RepoReminderEventFromMessage creates a new repo reminder event from a message

Jump to