Documentation
¶
Overview ¶
Package clients defines the shared client interface used by github repo management code
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GitHubRepoClient ¶
type GitHubRepoClient interface {
GetRepository(context.Context, string, string) (*github.Repository, error)
CreateHook(ctx context.Context, owner, repo string, hook *github.Hook) (*github.Hook, error)
DeleteHook(ctx context.Context, owner, repo string, id int64) (*github.Response, error)
ListHooks(ctx context.Context, owner, repo string) ([]*github.Hook, error)
}
GitHubRepoClient defines a subset of the GitHub API client which we need for webhook management. This allows us to create a stub which only includes the methods which we care about
Directories
¶
| Path | Synopsis |
|---|---|
|
Package mock_clients is a generated GoMock package.
|
Package mock_clients is a generated GoMock package. |
|
fixtures
Package fixtures contains fixtures used within the github repositories package.
|
Package fixtures contains fixtures used within the github repositories package. |
Click to show internal directories.
Click to hide internal directories.