mock_clients

package
v0.0.56 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 18, 2024 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package mock_clients is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockGitHubRepoClient

type MockGitHubRepoClient struct {
	// contains filtered or unexported fields
}

MockGitHubRepoClient is a mock of GitHubRepoClient interface.

func NewMockGitHubRepoClient

func NewMockGitHubRepoClient(ctrl *gomock.Controller) *MockGitHubRepoClient

NewMockGitHubRepoClient creates a new mock instance.

func (*MockGitHubRepoClient) CreateHook

func (m *MockGitHubRepoClient) CreateHook(ctx context.Context, owner, repo string, hook *github.Hook) (*github.Hook, error)

CreateHook mocks base method.

func (*MockGitHubRepoClient) DeleteHook

func (m *MockGitHubRepoClient) DeleteHook(ctx context.Context, owner, repo string, id int64) (*github.Response, error)

DeleteHook mocks base method.

func (*MockGitHubRepoClient) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockGitHubRepoClient) GetRepository

func (m *MockGitHubRepoClient) GetRepository(arg0 context.Context, arg1, arg2 string) (*github.Repository, error)

GetRepository mocks base method.

func (*MockGitHubRepoClient) ListHooks

func (m *MockGitHubRepoClient) ListHooks(ctx context.Context, owner, repo string) ([]*github.Hook, error)

ListHooks mocks base method.

type MockGitHubRepoClientMockRecorder

type MockGitHubRepoClientMockRecorder struct {
	// contains filtered or unexported fields
}

MockGitHubRepoClientMockRecorder is the mock recorder for MockGitHubRepoClient.

func (*MockGitHubRepoClientMockRecorder) CreateHook

func (mr *MockGitHubRepoClientMockRecorder) CreateHook(ctx, owner, repo, hook any) *gomock.Call

CreateHook indicates an expected call of CreateHook.

func (*MockGitHubRepoClientMockRecorder) DeleteHook

func (mr *MockGitHubRepoClientMockRecorder) DeleteHook(ctx, owner, repo, id any) *gomock.Call

DeleteHook indicates an expected call of DeleteHook.

func (*MockGitHubRepoClientMockRecorder) GetRepository

func (mr *MockGitHubRepoClientMockRecorder) GetRepository(arg0, arg1, arg2 any) *gomock.Call

GetRepository indicates an expected call of GetRepository.

func (*MockGitHubRepoClientMockRecorder) ListHooks

func (mr *MockGitHubRepoClientMockRecorder) ListHooks(ctx, owner, repo any) *gomock.Call

ListHooks indicates an expected call of ListHooks.

Directories

Path Synopsis
Package fixtures contains fixtures used within the github repositories package.
Package fixtures contains fixtures used within the github repositories package.

Jump to