mockrulesvc

package
v0.0.43 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 11, 2024 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Overview

Package mockrulesvc is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockRuleTypeService

type MockRuleTypeService struct {
	// contains filtered or unexported fields
}

MockRuleTypeService is a mock of RuleTypeService interface.

func NewMockRuleTypeService

func NewMockRuleTypeService(ctrl *gomock.Controller) *MockRuleTypeService

NewMockRuleTypeService creates a new mock instance.

func (*MockRuleTypeService) CreateRuleType

func (m *MockRuleTypeService) CreateRuleType(arg0 context.Context, arg1, arg2 uuid.UUID, arg3 *v1.RuleType, arg4 db.Querier) (*v1.RuleType, error)

CreateRuleType mocks base method.

func (*MockRuleTypeService) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockRuleTypeService) UpdateRuleType

func (m *MockRuleTypeService) UpdateRuleType(arg0 context.Context, arg1, arg2 uuid.UUID, arg3 *v1.RuleType, arg4 db.Querier) (*v1.RuleType, error)

UpdateRuleType mocks base method.

func (*MockRuleTypeService) UpsertRuleType added in v0.0.38

func (m *MockRuleTypeService) UpsertRuleType(arg0 context.Context, arg1, arg2 uuid.UUID, arg3 *v1.RuleType, arg4 db.Querier) error

UpsertRuleType mocks base method.

type MockRuleTypeServiceMockRecorder

type MockRuleTypeServiceMockRecorder struct {
	// contains filtered or unexported fields
}

MockRuleTypeServiceMockRecorder is the mock recorder for MockRuleTypeService.

func (*MockRuleTypeServiceMockRecorder) CreateRuleType

func (mr *MockRuleTypeServiceMockRecorder) CreateRuleType(arg0, arg1, arg2, arg3, arg4 any) *gomock.Call

CreateRuleType indicates an expected call of CreateRuleType.

func (*MockRuleTypeServiceMockRecorder) UpdateRuleType

func (mr *MockRuleTypeServiceMockRecorder) UpdateRuleType(arg0, arg1, arg2, arg3, arg4 any) *gomock.Call

UpdateRuleType indicates an expected call of UpdateRuleType.

func (*MockRuleTypeServiceMockRecorder) UpsertRuleType added in v0.0.38

func (mr *MockRuleTypeServiceMockRecorder) UpsertRuleType(arg0, arg1, arg2, arg3, arg4 any) *gomock.Call

UpsertRuleType indicates an expected call of UpsertRuleType.

Directories

Path Synopsis
Package fixtures contains code for creating ProfileService fixtures and is used in various parts of the code.
Package fixtures contains code for creating ProfileService fixtures and is used in various parts of the code.

Jump to