Documentation
¶
Overview ¶
Package sigstore provides a client for verifying artifacts using sigstore
Index ¶
Constants ¶
const (
// SigstorePublicTrustedRootRepo is the public trusted root repository for sigstore
SigstorePublicTrustedRootRepo = "tuf-repo-cdn.sigstore.dev"
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Sigstore ¶
type Sigstore struct {
// contains filtered or unexported fields
}
Sigstore is the sigstore verifier
func (*Sigstore) VerifyContainer ¶
func (s *Sigstore) VerifyContainer(ctx context.Context, registry, owner, artifact, version string) ( json.RawMessage, json.RawMessage, error)
VerifyContainer verifies a container artifact using sigstore
Click to show internal directories.
Click to hide internal directories.