app

package
v0.0.14 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 6, 2023 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Overview

Package app provides the root command for the minder CLI

Index

Constants

const JSON = "json"

JSON is the json format for output

const Table = "table"

Table is the table format for output

const YAML = "yaml"

YAML is the yaml format for output

Variables

var (

	// RootCmd represents the base command when called without any subcommands
	RootCmd = &cobra.Command{
		Use:   "minder",
		Short: "Minder controls the hosted minder service",
		Long: `For more information about minder, please visit:
https://docs.stacklok.com/minder`,
	}
)

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately.

Types

This section is empty.

Directories

Path Synopsis
Package artifact provides the artifact subcommands
Package artifact provides the artifact subcommands
Package auth provides the auth command project for the minder CLI.
Package auth provides the auth command project for the minder CLI.
Package apply provides the apply command for the minder CLI
Package apply provides the apply command for the minder CLI
Package profile provides the CLI subcommand for managing profiles
Package profile provides the CLI subcommand for managing profiles
Package profile_status provides the CLI subcommand for managing profile statuses
Package profile_status provides the CLI subcommand for managing profile statuses
Package provider is the root command for the provider subcommands
Package provider is the root command for the provider subcommands
Package repo contains the repo logic for the control plane
Package repo contains the repo logic for the control plane
Package rule_type provides the CLI subcommand for managing rules
Package rule_type provides the CLI subcommand for managing rules
Package version provides the version command for the minder CLI
Package version provides the version command for the minder CLI

Jump to