Documentation
¶
Overview ¶
Package repo contains the repo logic for the control plane
Index ¶
Constants ¶
This section is empty.
Variables ¶
var RepoCmd = &cobra.Command{ Use: "repo", Short: "Manage repositories within a minder control plane", Long: `The minder repo commands allow the management of repositories within a minder control plane.`, RunE: func(cmd *cobra.Command, args []string) error { return cmd.Usage() }, }
RepoCmd is the root command for the repo subcommands
Functions ¶
func RegisterCmd ¶ added in v0.0.17
func RegisterCmd(ctx context.Context, cmd *cobra.Command, conn *grpc.ClientConn) ([]*pb.RegisterRepoResult, string, error)
RegisterCmd represents the register command to register a repo with minder
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.