app

package
v0.0.15 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 9, 2023 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package app provides the root command for the medev CLI

Index

Constants

This section is empty.

Variables

var (

	// RootCmd represents the base command when called without any subcommands
	RootCmd = &cobra.Command{
		Use:   "medev",
		Short: "medev provides developer tooling for minder",
		Long: `For more information about minder, please visit:
https://docs.stacklok.com/minder`,
	}
)

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately.

Types

This section is empty.

Directories

Path Synopsis
Package rule_type provides the CLI subcommand for developing rules e.g.
Package rule_type provides the CLI subcommand for developing rules e.g.

Jump to