Documentation
¶
Overview ¶
Package auth is a generated GoMock package.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockJwtValidator ¶
type MockJwtValidator struct {
// contains filtered or unexported fields
}
MockJwtValidator is a mock of JwtValidator interface.
func NewMockJwtValidator ¶
func NewMockJwtValidator(ctrl *gomock.Controller) *MockJwtValidator
NewMockJwtValidator creates a new mock instance.
func (*MockJwtValidator) EXPECT ¶
func (m *MockJwtValidator) EXPECT() *MockJwtValidatorMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockJwtValidator) ParseAndValidate ¶
func (m *MockJwtValidator) ParseAndValidate(arg0 string) (openid.Token, error)
ParseAndValidate mocks base method.
type MockJwtValidatorMockRecorder ¶
type MockJwtValidatorMockRecorder struct {
// contains filtered or unexported fields
}
MockJwtValidatorMockRecorder is the mock recorder for MockJwtValidator.
func (*MockJwtValidatorMockRecorder) ParseAndValidate ¶
func (mr *MockJwtValidatorMockRecorder) ParseAndValidate(arg0 interface{}) *gomock.Call
ParseAndValidate indicates an expected call of ParseAndValidate.
type MockKeySetFetcher ¶
type MockKeySetFetcher struct {
// contains filtered or unexported fields
}
MockKeySetFetcher is a mock of KeySetFetcher interface.
func NewMockKeySetFetcher ¶
func NewMockKeySetFetcher(ctrl *gomock.Controller) *MockKeySetFetcher
NewMockKeySetFetcher creates a new mock instance.
func (*MockKeySetFetcher) EXPECT ¶
func (m *MockKeySetFetcher) EXPECT() *MockKeySetFetcherMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockKeySetFetcherMockRecorder ¶
type MockKeySetFetcherMockRecorder struct {
// contains filtered or unexported fields
}
MockKeySetFetcherMockRecorder is the mock recorder for MockKeySetFetcher.
func (*MockKeySetFetcherMockRecorder) GetKeySet ¶
func (mr *MockKeySetFetcherMockRecorder) GetKeySet() *gomock.Call
GetKeySet indicates an expected call of GetKeySet.