Documentation
¶
Overview ¶
Package entities contains logic relating to entity management
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EntityFromIDs ¶ added in v0.0.53
func EntityFromIDs( repositoryID uuid.UUID, artifactID uuid.UUID, pullRequestID uuid.UUID, ) (uuid.UUID, db.Entities, error)
EntityFromIDs takes the IDs of the three known entity types and returns a single ID along with the type of the entity. This assumes that exactly one of the IDs is not equal to uuid.Nil
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package checkpoints contains logic relating to checkpoint management for entities
|
Package checkpoints contains logic relating to checkpoint management for entities |
|
Package models contains domain models for entities
|
Package models contains domain models for entities |
|
Package properties provides a simple way to access properties of an entity
|
Package properties provides a simple way to access properties of an entity |
|
service
Package service provides a service to interact with properties of an entity
|
Package service provides a service to interact with properties of an entity |
|
service/mock
Package mock_service is a generated GoMock package.
|
Package mock_service is a generated GoMock package. |
Click to show internal directories.
Click to hide internal directories.