entities

package
v0.0.19 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 28, 2023 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package entities contains internal helper functions to deal with, validate and print the Entity protobuf enum. Mostly to interact with the database.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func EntityTypeFromDB

func EntityTypeFromDB(entity db.Entities) minderv1.Entity

EntityTypeFromDB returns the entity type from the database entity

func EntityTypeToDB

func EntityTypeToDB(entity minderv1.Entity) db.Entities

EntityTypeToDB returns the database entity from the protobuf entity type

func KnownTypesCSV

func KnownTypesCSV() string

KnownTypesCSV returns a comma separated list of known entity types. Useful for UI

Types

This section is empty.

Jump to