projects

package
v0.0.35 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 13, 2024 License: Apache-2.0 Imports: 14 Imported by: 0

Documentation

Overview

Package projects contains utilities for working with projects.

Index

Constants

const (
	// MinderMetadataVersion is the version of the metadata format.
	MinderMetadataVersion = "v1alpha1"
)

Variables

This section is empty.

Functions

func CleanUpUnmanagedProjects

func CleanUpUnmanagedProjects(ctx context.Context, proj uuid.UUID, querier db.Querier, authzClient authz.Client) error

CleanUpUnmanagedProjects deletes a project if it has no role assignments left

func DeleteProject

func DeleteProject(ctx context.Context, proj uuid.UUID, querier db.Querier, authzClient authz.Client) error

DeleteProject deletes a project and authorization relationships

func ProvisionSelfEnrolledProject

func ProvisionSelfEnrolledProject(
	ctx context.Context,
	authzClient authz.Client,
	qtx db.Querier,
	projectName string,
	userSub string,
) (outproj *pb.Project, projerr error)

ProvisionSelfEnrolledProject creates the default records, such as projects, roles and provider for the organization

Types

type Metadata

type Metadata struct {
	Version      string `json:"version"`
	SelfEnrolled bool   `json:"self_enrolled"`
	Description  string `json:"description"`
}

Metadata contains metadata relevant for a project.

func NewSelfEnrolledMetadata

func NewSelfEnrolledMetadata() Metadata

NewSelfEnrolledMetadata returns a new Metadata object with the SelfEnrolled field set to true.

Directories

Path Synopsis
Package features provides the features checks for the projects
Package features provides the features checks for the projects

Jump to