Documentation
¶
Overview ¶
Package messages contains the messages used by the reminder service
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type RepoReminderEvent ¶
type RepoReminderEvent struct {
// Project is the project that the event is relevant to
Project uuid.UUID `json:"project"`
// ProviderID is the provider of the repository
ProviderID uuid.UUID `json:"provider"`
// RepositoryID is id of the repository to be reconciled
RepositoryID int64 `json:"repository"`
}
RepoReminderEvent is an event that is published by the reminder service to trigger repo reconciliation
func RepoReminderEventFromMessage ¶
func RepoReminderEventFromMessage(msg *message.Message) (*RepoReminderEvent, error)
RepoReminderEventFromMessage creates a new repo reminder event from a message
Click to show internal directories.
Click to hide internal directories.