clients

package
v0.0.38 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 28, 2024 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package clients defines the shared client interface used by github repo management code

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type GitHubRepoClient

type GitHubRepoClient interface {
	GetRepository(context.Context, string, string) (*github.Repository, error)
	CreateHook(ctx context.Context, owner, repo string, hook *github.Hook) (*github.Hook, error)
	DeleteHook(ctx context.Context, owner, repo string, id int64) (*github.Response, error)
	ListHooks(ctx context.Context, owner, repo string) ([]*github.Hook, error)
}

GitHubRepoClient defines a subset of the GitHub API client which we need for repo and webhook management. This allows us to create a stub which only includes the methods which we care about

Directories

Path Synopsis
Package mockghclients is a generated GoMock package.
Package mockghclients is a generated GoMock package.

Jump to