Documentation
¶
Overview ¶
Package cli contains utility for the cli
Index ¶
- Variables
- func GRPCClientWrapRunE(...) func(cmd *cobra.Command, args []string) error
- func GetAppContext(ctx context.Context, v *viper.Viper) (context.Context, context.CancelFunc)
- func GetAppContextWithTimeoutDuration(ctx context.Context, v *viper.Viper, tout int) (context.Context, context.CancelFunc)
- func GrpcForCommand(cmd *cobra.Command, v *viper.Viper) (*grpc.ClientConn, error)
- func MessageAndError(cmd *cobra.Command, msg string, err error) error
- func PrintYesNoPrompt(cmd *cobra.Command, promptMsg, confirmMsg, fallbackMsg string, defaultYes bool) bool
- func TableRender(t table.Model) string
Constants ¶
This section is empty.
Variables ¶
var ( // PrimaryColor is the primary color for the cli. PrimaryColor = lipgloss.Color("#00BBBE") // Secondary is the secondary color for the cli. SecondaryColor = lipgloss.Color("#59CFA8") // AccentColor is the accent color for the cli. AccentColor = lipgloss.Color("#3D34E0") // WhiteColor is the white color for the cli. WhiteColor = lipgloss.Color("#FFFFFF") // BlackColor is the black color for the cli. BlackColor = lipgloss.Color("#000000") )
Color Palette
var ( // DefaultBannerWidth is the default width for a banner DefaultBannerWidth = 80 // Header is the style to use for headers Header = lipgloss.NewStyle(). Bold(true). Foreground(PrimaryColor). PaddingTop(1). PaddingBottom(1). PaddingLeft(1). PaddingRight(1). MaxWidth(80) WarningBanner = lipgloss.NewStyle(). Bold(true). Background(BlackColor). Foreground(WhiteColor). BorderForeground(AccentColor). PaddingTop(2). PaddingBottom(2). PaddingLeft(4). PaddingRight(4). Width(DefaultBannerWidth) // SuccessBanner is the style to use for a success banner SuccessBanner = lipgloss.NewStyle(). Bold(true). Background(AccentColor). Foreground(WhiteColor). PaddingTop(1). PaddingBottom(1). PaddingLeft(4). PaddingRight(4). Width(DefaultBannerWidth) // Table is the style to use for tables Table = lipgloss.NewStyle(). BorderStyle(lipgloss.NormalBorder()). BorderForeground(AccentColor) // TableStyles is the style to use for tables TableStyles = table.Styles{ Selected: lipgloss.NewStyle().Bold(true).Foreground(SecondaryColor), Header: lipgloss.NewStyle().Bold(true).Padding(0, 1).Foreground(PrimaryColor), Cell: lipgloss.NewStyle().Padding(0, 1), } // TableHiddenSelectStyles is the style to use for tables. It hides the selection // indicator. TableHiddenSelectStyles = table.Styles{ Header: lipgloss.NewStyle().Bold(true).Padding(0, 1).Foreground(PrimaryColor), Cell: lipgloss.NewStyle().Padding(0, 1), Selected: lipgloss.NewStyle(), } KeyValTableWidths = struct { Key int Value int }{ Key: keyWidth, Value: DefaultBannerWidth - keyWidth - 6, } )
Styles
Functions ¶
func GRPCClientWrapRunE ¶ added in v0.0.20
func GRPCClientWrapRunE( runEFunc func(ctx context.Context, cmd *cobra.Command, c *grpc.ClientConn) error, ) func(cmd *cobra.Command, args []string) error
GRPCClientWrapRunE is a wrapper for cobra commands that sets up the grpc client and context
func GetAppContext ¶ added in v0.0.20
GetAppContext is a helper for getting the cmd app context
func GetAppContextWithTimeoutDuration ¶ added in v0.0.21
func GetAppContextWithTimeoutDuration(ctx context.Context, v *viper.Viper, tout int) (context.Context, context.CancelFunc)
GetAppContextWithTimeoutDuration is a helper for getting the cmd app context with a custom timeout
func GrpcForCommand ¶ added in v0.0.20
GrpcForCommand is a helper for getting a testing connection from cobra flags
func MessageAndError ¶ added in v0.0.21
MessageAndError prints a message and returns an error.
func PrintYesNoPrompt ¶
func PrintYesNoPrompt(cmd *cobra.Command, promptMsg, confirmMsg, fallbackMsg string, defaultYes bool) bool
PrintYesNoPrompt prints a yes/no prompt to the user and returns false if the user did not respond with yes or y
func TableRender ¶
TableRender renders a table given a table model
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.