Documentation
¶
Overview ¶
Package cli contains utility for the cli
Index ¶
Constants ¶
const (
// DefaultBannerWidth is the default width for a banner
DefaultBannerWidth = 100
)
Variables ¶
var ( // PrimaryColor is the primary color for the cli. PrimaryColor = lipgloss.Color("#00BBBE") // Secondary is the secondary color for the cli. SecondaryColor = lipgloss.Color("#59CFA8") // AccentColor is the accent color for the cli. AccentColor = lipgloss.Color("#3D34E0") // WhiteColor is the white color for the cli. WhiteColor = lipgloss.Color("#FFFFFF") // BlackColor is the black color for the cli. BlackColor = lipgloss.Color("#000000") )
Color Palette
var ( // Header is the style to use for headers Header = lipgloss.NewStyle(). Bold(true). Foreground(PrimaryColor). PaddingTop(1). PaddingBottom(1). PaddingLeft(1). PaddingRight(1). MaxWidth(80) WarningBanner = lipgloss.NewStyle(). Bold(true). Background(BlackColor). Foreground(WhiteColor). BorderForeground(AccentColor). PaddingTop(2). PaddingBottom(2). PaddingLeft(4). PaddingRight(4). Width(DefaultBannerWidth) // SuccessBanner is the style to use for a success banner SuccessBanner = lipgloss.NewStyle(). Bold(true). Background(AccentColor). Foreground(WhiteColor). PaddingTop(1). PaddingBottom(1). PaddingLeft(4). PaddingRight(4). Width(DefaultBannerWidth) // Table is the style to use for tables Table = lipgloss.NewStyle(). BorderStyle(lipgloss.NormalBorder()). BorderForeground(AccentColor) // TableStyles is the style to use for tables TableStyles = table.Styles{ Selected: lipgloss.NewStyle().Bold(true).Foreground(SecondaryColor), Header: lipgloss.NewStyle().Bold(true).Padding(0, 1).Foreground(PrimaryColor), Cell: lipgloss.NewStyle().Padding(0, 1), } // TableHiddenSelectStyles is the style to use for tables. It hides the selection // indicator. TableHiddenSelectStyles = table.Styles{ Header: lipgloss.NewStyle().Bold(true).Padding(0, 1).Foreground(PrimaryColor), Cell: lipgloss.NewStyle().Padding(0, 1), Selected: lipgloss.NewStyle(), } KeyValTableWidths = struct { Key int Value int }{ Key: 27, Value: 67, } )
Styles
Functions ¶
func PrintYesNoPrompt ¶
PrintYesNoPrompt prints a yes/no prompt to the user and returns false if the user did not respond with yes or y
func TableRender ¶
TableRender renders a table given a table model
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.